// Code generated by wincallback.go using 'go generate'. DO NOT EDIT.

//go:build darwin || freebsd || linux || netbsd

// External code calls into callbackasm at an offset corresponding
// to the callback index. Callbackasm is a table of MOVV and JMP instructions.
// The MOVV instruction loads R12 with the callback index, and the
// JMP instruction branches to callbackasm1.
// callbackasm1 takes the callback index from R12 and
// indexes into an array that stores information about each callback.
// It then calls the Go implementation for that callback.
#include "textflag.h"

TEXT callbackasm(SB), NOSPLIT|NOFRAME, $0
	MOVV $0, R12
	JMP  callbackasm1(SB)
	MOVV $1, R12
	JMP  callbackasm1(SB)
	MOVV $2, R12
	JMP  callbackasm1(SB)
	MOVV $3, R12
	JMP  callbackasm1(SB)
	MOVV $4, R12
	JMP  callbackasm1(SB)
	MOVV $5, R12
	JMP  callbackasm1(SB)
	MOVV $6, R12
	JMP  callbackasm1(SB)
	MOVV $7, R12
	JMP  callbackasm1(SB)
	MOVV $8, R12
	JMP  callbackasm1(SB)
	MOVV $9, R12
	JMP  callbackasm1(SB)
	MOVV $10, R12
	JMP  callbackasm1(SB)
	MOVV $11, R12
	JMP  callbackasm1(SB)
	MOVV $12, R12
	JMP  callbackasm1(SB)
	MOVV $13, R12
	JMP  callbackasm1(SB)
	MOVV $14, R12
	JMP  callbackasm1(SB)
	MOVV $15, R12
	JMP  callbackasm1(SB)
	MOVV $16, R12
	JMP  callbackasm1(SB)
	MOVV $17, R12
	JMP  callbackasm1(SB)
	MOVV $18, R12
	JMP  callbackasm1(SB)
	MOVV $19, R12
	JMP  callbackasm1(SB)
	MOVV $20, R12
	JMP  callbackasm1(SB)
	MOVV $21, R12
	JMP  callbackasm1(SB)
	MOVV $22, R12
	JMP  callbackasm1(SB)
	MOVV $23, R12
	JMP  callbackasm1(SB)
	MOVV $24, R12
	JMP  callbackasm1(SB)
	MOVV $25, R12
	JMP  callbackasm1(SB)
	MOVV $26, R12
	JMP  callbackasm1(SB)
	MOVV $27, R12
	JMP  callbackasm1(SB)
	MOVV $28, R12
	JMP  callbackasm1(SB)
	MOVV $29, R12
	JMP  callbackasm1(SB)
	MOVV $30, R12
	JMP  callbackasm1(SB)
	MOVV $31, R12
	JMP  callbackasm1(SB)
	MOVV $32, R12
	JMP  callbackasm1(SB)
	MOVV $33, R12
	JMP  callbackasm1(SB)
	MOVV $34, R12
	JMP  callbackasm1(SB)
	MOVV $35, R12
	JMP  callbackasm1(SB)
	MOVV $36, R12
	JMP  callbackasm1(SB)
	MOVV $37, R12
	JMP  callbackasm1(SB)
	MOVV $38, R12
	JMP  callbackasm1(SB)
	MOVV $39, R12
	JMP  callbackasm1(SB)
	MOVV $40, R12
	JMP  callbackasm1(SB)
	MOVV $41, R12
	JMP  callbackasm1(SB)
	MOVV $42, R12
	JMP  callbackasm1(SB)
	MOVV $43, R12
	JMP  callbackasm1(SB)
	MOVV $44, R12
	JMP  callbackasm1(SB)
	MOVV $45, R12
	JMP  callbackasm1(SB)
	MOVV $46, R12
	JMP  callbackasm1(SB)
	MOVV $47, R12
	JMP  callbackasm1(SB)
	MOVV $48, R12
	JMP  callbackasm1(SB)
	MOVV $49, R12
	JMP  callbackasm1(SB)
	MOVV $50, R12
	JMP  callbackasm1(SB)
	MOVV $51, R12
	JMP  callbackasm1(SB)
	MOVV $52, R12
	JMP  callbackasm1(SB)
	MOVV $53, R12
	JMP  callbackasm1(SB)
	MOVV $54, R12
	JMP  callbackasm1(SB)
	MOVV $55, R12
	JMP  callbackasm1(SB)
	MOVV $56, R12
	JMP  callbackasm1(SB)
	MOVV $57, R12
	JMP  callbackasm1(SB)
	MOVV $58, R12
	JMP  callbackasm1(SB)
	MOVV $59, R12
	JMP  callbackasm1(SB)
	MOVV $60, R12
	JMP  callbackasm1(SB)
	MOVV $61, R12
	JMP  callbackasm1(SB)
	MOVV $62, R12
	JMP  callbackasm1(SB)
	MOVV $63, R12
	JMP  callbackasm1(SB)
	MOVV $64, R12
	JMP  callbackasm1(SB)
	MOVV $65, R12
	JMP  callbackasm1(SB)
	MOVV $66, R12
	JMP  callbackasm1(SB)
	MOVV $67, R12
	JMP  callbackasm1(SB)
	MOVV $68, R12
	JMP  callbackasm1(SB)
	MOVV $69, R12
	JMP  callbackasm1(SB)
	MOVV $70, R12
	JMP  callbackasm1(SB)
	MOVV $71, R12
	JMP  callbackasm1(SB)
	MOVV $72, R12
	JMP  callbackasm1(SB)
	MOVV $73, R12
	JMP  callbackasm1(SB)
	MOVV $74, R12
	JMP  callbackasm1(SB)
	MOVV $75, R12
	JMP  callbackasm1(SB)
	MOVV $76, R12
	JMP  callbackasm1(SB)
	MOVV $77, R12
	JMP  callbackasm1(SB)
	MOVV $78, R12
	JMP  callbackasm1(SB)
	MOVV $79, R12
	JMP  callbackasm1(SB)
	MOVV $80, R12
	JMP  callbackasm1(SB)
	MOVV $81, R12
	JMP  callbackasm1(SB)
	MOVV $82, R12
	JMP  callbackasm1(SB)
	MOVV $83, R12
	JMP  callbackasm1(SB)
	MOVV $84, R12
	JMP  callbackasm1(SB)
	MOVV $85, R12
	JMP  callbackasm1(SB)
	MOVV $86, R12
	JMP  callbackasm1(SB)
	MOVV $87, R12
	JMP  callbackasm1(SB)
	MOVV $88, R12
	JMP  callbackasm1(SB)
	MOVV $89, R12
	JMP  callbackasm1(SB)
	MOVV $90, R12
	JMP  callbackasm1(SB)
	MOVV $91, R12
	JMP  callbackasm1(SB)
	MOVV $92, R12
	JMP  callbackasm1(SB)
	MOVV $93, R12
	JMP  callbackasm1(SB)
	MOVV $94, R12
	JMP  callbackasm1(SB)
	MOVV $95, R12
	JMP  callbackasm1(SB)
	MOVV $96, R12
	JMP  callbackasm1(SB)
	MOVV $97, R12
	JMP  callbackasm1(SB)
	MOVV $98, R12
	JMP  callbackasm1(SB)
	MOVV $99, R12
	JMP  callbackasm1(SB)
	MOVV $100, R12
	JMP  callbackasm1(SB)
	MOVV $101, R12
	JMP  callbackasm1(SB)
	MOVV $102, R12
	JMP  callbackasm1(SB)
	MOVV $103, R12
	JMP  callbackasm1(SB)
	MOVV $104, R12
	JMP  callbackasm1(SB)
	MOVV $105, R12
	JMP  callbackasm1(SB)
	MOVV $106, R12
	JMP  callbackasm1(SB)
	MOVV $107, R12
	JMP  callbackasm1(SB)
	MOVV $108, R12
	JMP  callbackasm1(SB)
	MOVV $109, R12
	JMP  callbackasm1(SB)
	MOVV $110, R12
	JMP  callbackasm1(SB)
	MOVV $111, R12
	JMP  callbackasm1(SB)
	MOVV $112, R12
	JMP  callbackasm1(SB)
	MOVV $113, R12
	JMP  callbackasm1(SB)
	MOVV $114, R12
	JMP  callbackasm1(SB)
	MOVV $115, R12
	JMP  callbackasm1(SB)
	MOVV $116, R12
	JMP  callbackasm1(SB)
	MOVV $117, R12
	JMP  callbackasm1(SB)
	MOVV $118, R12
	JMP  callbackasm1(SB)
	MOVV $119, R12
	JMP  callbackasm1(SB)
	MOVV $120, R12
	JMP  callbackasm1(SB)
	MOVV $121, R12
	JMP  callbackasm1(SB)
	MOVV $122, R12
	JMP  callbackasm1(SB)
	MOVV $123, R12
	JMP  callbackasm1(SB)
	MOVV $124, R12
	JMP  callbackasm1(SB)
	MOVV $125, R12
	JMP  callbackasm1(SB)
	MOVV $126, R12
	JMP  callbackasm1(SB)
	MOVV $127, R12
	JMP  callbackasm1(SB)
	MOVV $128, R12
	JMP  callbackasm1(SB)
	MOVV $129, R12
	JMP  callbackasm1(SB)
	MOVV $130, R12
	JMP  callbackasm1(SB)
	MOVV $131, R12
	JMP  callbackasm1(SB)
	MOVV $132, R12
	JMP  callbackasm1(SB)
	MOVV $133, R12
	JMP  callbackasm1(SB)
	MOVV $134, R12
	JMP  callbackasm1(SB)
	MOVV $135, R12
	JMP  callbackasm1(SB)
	MOVV $136, R12
	JMP  callbackasm1(SB)
	MOVV $137, R12
	JMP  callbackasm1(SB)
	MOVV $138, R12
	JMP  callbackasm1(SB)
	MOVV $139, R12
	JMP  callbackasm1(SB)
	MOVV $140, R12
	JMP  callbackasm1(SB)
	MOVV $141, R12
	JMP  callbackasm1(SB)
	MOVV $142, R12
	JMP  callbackasm1(SB)
	MOVV $143, R12
	JMP  callbackasm1(SB)
	MOVV $144, R12
	JMP  callbackasm1(SB)
	MOVV $145, R12
	JMP  callbackasm1(SB)
	MOVV $146, R12
	JMP  callbackasm1(SB)
	MOVV $147, R12
	JMP  callbackasm1(SB)
	MOVV $148, R12
	JMP  callbackasm1(SB)
	MOVV $149, R12
	JMP  callbackasm1(SB)
	MOVV $150, R12
	JMP  callbackasm1(SB)
	MOVV $151, R12
	JMP  callbackasm1(SB)
	MOVV $152, R12
	JMP  callbackasm1(SB)
	MOVV $153, R12
	JMP  callbackasm1(SB)
	MOVV $154, R12
	JMP  callbackasm1(SB)
	MOVV $155, R12
	JMP  callbackasm1(SB)
	MOVV $156, R12
	JMP  callbackasm1(SB)
	MOVV $157, R12
	JMP  callbackasm1(SB)
	MOVV $158, R12
	JMP  callbackasm1(SB)
	MOVV $159, R12
	JMP  callbackasm1(SB)
	MOVV $160, R12
	JMP  callbackasm1(SB)
	MOVV $161, R12
	JMP  callbackasm1(SB)
	MOVV $162, R12
	JMP  callbackasm1(SB)
	MOVV $163, R12
	JMP  callbackasm1(SB)
	MOVV $164, R12
	JMP  callbackasm1(SB)
	MOVV $165, R12
	JMP  callbackasm1(SB)
	MOVV $166, R12
	JMP  callbackasm1(SB)
	MOVV $167, R12
	JMP  callbackasm1(SB)
	MOVV $168, R12
	JMP  callbackasm1(SB)
	MOVV $169, R12
	JMP  callbackasm1(SB)
	MOVV $170, R12
	JMP  callbackasm1(SB)
	MOVV $171, R12
	JMP  callbackasm1(SB)
	MOVV $172, R12
	JMP  callbackasm1(SB)
	MOVV $173, R12
	JMP  callbackasm1(SB)
	MOVV $174, R12
	JMP  callbackasm1(SB)
	MOVV $175, R12
	JMP  callbackasm1(SB)
	MOVV $176, R12
	JMP  callbackasm1(SB)
	MOVV $177, R12
	JMP  callbackasm1(SB)
	MOVV $178, R12
	JMP  callbackasm1(SB)
	MOVV $179, R12
	JMP  callbackasm1(SB)
	MOVV $180, R12
	JMP  callbackasm1(SB)
	MOVV $181, R12
	JMP  callbackasm1(SB)
	MOVV $182, R12
	JMP  callbackasm1(SB)
	MOVV $183, R12
	JMP  callbackasm1(SB)
	MOVV $184, R12
	JMP  callbackasm1(SB)
	MOVV $185, R12
	JMP  callbackasm1(SB)
	MOVV $186, R12
	JMP  callbackasm1(SB)
	MOVV $187, R12
	JMP  callbackasm1(SB)
	MOVV $188, R12
	JMP  callbackasm1(SB)
	MOVV $189, R12
	JMP  callbackasm1(SB)
	MOVV $190, R12
	JMP  callbackasm1(SB)
	MOVV $191, R12
	JMP  callbackasm1(SB)
	MOVV $192, R12
	JMP  callbackasm1(SB)
	MOVV $193, R12
	JMP  callbackasm1(SB)
	MOVV $194, R12
	JMP  callbackasm1(SB)
	MOVV $195, R12
	JMP  callbackasm1(SB)
	MOVV $196, R12
	JMP  callbackasm1(SB)
	MOVV $197, R12
	JMP  callbackasm1(SB)
	MOVV $198, R12
	JMP  callbackasm1(SB)
	MOVV $199, R12
	JMP  callbackasm1(SB)
	MOVV $200, R12
	JMP  callbackasm1(SB)
	MOVV $201, R12
	JMP  callbackasm1(SB)
	MOVV $202, R12
	JMP  callbackasm1(SB)
	MOVV $203, R12
	JMP  callbackasm1(SB)
	MOVV $204, R12
	JMP  callbackasm1(SB)
	MOVV $205, R12
	JMP  callbackasm1(SB)
	MOVV $206, R12
	JMP  callbackasm1(SB)
	MOVV $207, R12
	JMP  callbackasm1(SB)
	MOVV $208, R12
	JMP  callbackasm1(SB)
	MOVV $209, R12
	JMP  callbackasm1(SB)
	MOVV $210, R12
	JMP  callbackasm1(SB)
	MOVV $211, R12
	JMP  callbackasm1(SB)
	MOVV $212, R12
	JMP  callbackasm1(SB)
	MOVV $213, R12
	JMP  callbackasm1(SB)
	MOVV $214, R12
	JMP  callbackasm1(SB)
	MOVV $215, R12
	JMP  callbackasm1(SB)
	MOVV $216, R12
	JMP  callbackasm1(SB)
	MOVV $217, R12
	JMP  callbackasm1(SB)
	MOVV $218, R12
	JMP  callbackasm1(SB)
	MOVV $219, R12
	JMP  callbackasm1(SB)
	MOVV $220, R12
	JMP  callbackasm1(SB)
	MOVV $221, R12
	JMP  callbackasm1(SB)
	MOVV $222, R12
	JMP  callbackasm1(SB)
	MOVV $223, R12
	JMP  callbackasm1(SB)
	MOVV $224, R12
	JMP  callbackasm1(SB)
	MOVV $225, R12
	JMP  callbackasm1(SB)
	MOVV $226, R12
	JMP  callbackasm1(SB)
	MOVV $227, R12
	JMP  callbackasm1(SB)
	MOVV $228, R12
	JMP  callbackasm1(SB)
	MOVV $229, R12
	JMP  callbackasm1(SB)
	MOVV $230, R12
	JMP  callbackasm1(SB)
	MOVV $231, R12
	JMP  callbackasm1(SB)
	MOVV $232, R12
	JMP  callbackasm1(SB)
	MOVV $233, R12
	JMP  callbackasm1(SB)
	MOVV $234, R12
	JMP  callbackasm1(SB)
	MOVV $235, R12
	JMP  callbackasm1(SB)
	MOVV $236, R12
	JMP  callbackasm1(SB)
	MOVV $237, R12
	JMP  callbackasm1(SB)
	MOVV $238, R12
	JMP  callbackasm1(SB)
	MOVV $239, R12
	JMP  callbackasm1(SB)
	MOVV $240, R12
	JMP  callbackasm1(SB)
	MOVV $241, R12
	JMP  callbackasm1(SB)
	MOVV $242, R12
	JMP  callbackasm1(SB)
	MOVV $243, R12
	JMP  callbackasm1(SB)
	MOVV $244, R12
	JMP  callbackasm1(SB)
	MOVV $245, R12
	JMP  callbackasm1(SB)
	MOVV $246, R12
	JMP  callbackasm1(SB)
	MOVV $247, R12
	JMP  callbackasm1(SB)
	MOVV $248, R12
	JMP  callbackasm1(SB)
	MOVV $249, R12
	JMP  callbackasm1(SB)
	MOVV $250, R12
	JMP  callbackasm1(SB)
	MOVV $251, R12
	JMP  callbackasm1(SB)
	MOVV $252, R12
	JMP  callbackasm1(SB)
	MOVV $253, R12
	JMP  callbackasm1(SB)
	MOVV $254, R12
	JMP  callbackasm1(SB)
	MOVV $255, R12
	JMP  callbackasm1(SB)
	MOVV $256, R12
	JMP  callbackasm1(SB)
	MOVV $257, R12
	JMP  callbackasm1(SB)
	MOVV $258, R12
	JMP  callbackasm1(SB)
	MOVV $259, R12
	JMP  callbackasm1(SB)
	MOVV $260, R12
	JMP  callbackasm1(SB)
	MOVV $261, R12
	JMP  callbackasm1(SB)
	MOVV $262, R12
	JMP  callbackasm1(SB)
	MOVV $263, R12
	JMP  callbackasm1(SB)
	MOVV $264, R12
	JMP  callbackasm1(SB)
	MOVV $265, R12
	JMP  callbackasm1(SB)
	MOVV $266, R12
	JMP  callbackasm1(SB)
	MOVV $267, R12
	JMP  callbackasm1(SB)
	MOVV $268, R12
	JMP  callbackasm1(SB)
	MOVV $269, R12
	JMP  callbackasm1(SB)
	MOVV $270, R12
	JMP  callbackasm1(SB)
	MOVV $271, R12
	JMP  callbackasm1(SB)
	MOVV $272, R12
	JMP  callbackasm1(SB)
	MOVV $273, R12
	JMP  callbackasm1(SB)
	MOVV $274, R12
	JMP  callbackasm1(SB)
	MOVV $275, R12
	JMP  callbackasm1(SB)
	MOVV $276, R12
	JMP  callbackasm1(SB)
	MOVV $277, R12
	JMP  callbackasm1(SB)
	MOVV $278, R12
	JMP  callbackasm1(SB)
	MOVV $279, R12
	JMP  callbackasm1(SB)
	MOVV $280, R12
	JMP  callbackasm1(SB)
	MOVV $281, R12
	JMP  callbackasm1(SB)
	MOVV $282, R12
	JMP  callbackasm1(SB)
	MOVV $283, R12
	JMP  callbackasm1(SB)
	MOVV $284, R12
	JMP  callbackasm1(SB)
	MOVV $285, R12
	JMP  callbackasm1(SB)
	MOVV $286, R12
	JMP  callbackasm1(SB)
	MOVV $287, R12
	JMP  callbackasm1(SB)
	MOVV $288, R12
	JMP  callbackasm1(SB)
	MOVV $289, R12
	JMP  callbackasm1(SB)
	MOVV $290, R12
	JMP  callbackasm1(SB)
	MOVV $291, R12
	JMP  callbackasm1(SB)
	MOVV $292, R12
	JMP  callbackasm1(SB)
	MOVV $293, R12
	JMP  callbackasm1(SB)
	MOVV $294, R12
	JMP  callbackasm1(SB)
	MOVV $295, R12
	JMP  callbackasm1(SB)
	MOVV $296, R12
	JMP  callbackasm1(SB)
	MOVV $297, R12
	JMP  callbackasm1(SB)
	MOVV $298, R12
	JMP  callbackasm1(SB)
	MOVV $299, R12
	JMP  callbackasm1(SB)
	MOVV $300, R12
	JMP  callbackasm1(SB)
	MOVV $301, R12
	JMP  callbackasm1(SB)
	MOVV $302, R12
	JMP  callbackasm1(SB)
	MOVV $303, R12
	JMP  callbackasm1(SB)
	MOVV $304, R12
	JMP  callbackasm1(SB)
	MOVV $305, R12
	JMP  callbackasm1(SB)
	MOVV $306, R12
	JMP  callbackasm1(SB)
	MOVV $307, R12
	JMP  callbackasm1(SB)
	MOVV $308, R12
	JMP  callbackasm1(SB)
	MOVV $309, R12
	JMP  callbackasm1(SB)
	MOVV $310, R12
	JMP  callbackasm1(SB)
	MOVV $311, R12
	JMP  callbackasm1(SB)
	MOVV $312, R12
	JMP  callbackasm1(SB)
	MOVV $313, R12
	JMP  callbackasm1(SB)
	MOVV $314, R12
	JMP  callbackasm1(SB)
	MOVV $315, R12
	JMP  callbackasm1(SB)
	MOVV $316, R12
	JMP  callbackasm1(SB)
	MOVV $317, R12
	JMP  callbackasm1(SB)
	MOVV $318, R12
	JMP  callbackasm1(SB)
	MOVV $319, R12
	JMP  callbackasm1(SB)
	MOVV $320, R12
	JMP  callbackasm1(SB)
	MOVV $321, R12
	JMP  callbackasm1(SB)
	MOVV $322, R12
	JMP  callbackasm1(SB)
	MOVV $323, R12
	JMP  callbackasm1(SB)
	MOVV $324, R12
	JMP  callbackasm1(SB)
	MOVV $325, R12
	JMP  callbackasm1(SB)
	MOVV $326, R12
	JMP  callbackasm1(SB)
	MOVV $327, R12
	JMP  callbackasm1(SB)
	MOVV $328, R12
	JMP  callbackasm1(SB)
	MOVV $329, R12
	JMP  callbackasm1(SB)
	MOVV $330, R12
	JMP  callbackasm1(SB)
	MOVV $331, R12
	JMP  callbackasm1(SB)
	MOVV $332, R12
	JMP  callbackasm1(SB)
	MOVV $333, R12
	JMP  callbackasm1(SB)
	MOVV $334, R12
	JMP  callbackasm1(SB)
	MOVV $335, R12
	JMP  callbackasm1(SB)
	MOVV $336, R12
	JMP  callbackasm1(SB)
	MOVV $337, R12
	JMP  callbackasm1(SB)
	MOVV $338, R12
	JMP  callbackasm1(SB)
	MOVV $339, R12
	JMP  callbackasm1(SB)
	MOVV $340, R12
	JMP  callbackasm1(SB)
	MOVV $341, R12
	JMP  callbackasm1(SB)
	MOVV $342, R12
	JMP  callbackasm1(SB)
	MOVV $343, R12
	JMP  callbackasm1(SB)
	MOVV $344, R12
	JMP  callbackasm1(SB)
	MOVV $345, R12
	JMP  callbackasm1(SB)
	MOVV $346, R12
	JMP  callbackasm1(SB)
	MOVV $347, R12
	JMP  callbackasm1(SB)
	MOVV $348, R12
	JMP  callbackasm1(SB)
	MOVV $349, R12
	JMP  callbackasm1(SB)
	MOVV $350, R12
	JMP  callbackasm1(SB)
	MOVV $351, R12
	JMP  callbackasm1(SB)
	MOVV $352, R12
	JMP  callbackasm1(SB)
	MOVV $353, R12
	JMP  callbackasm1(SB)
	MOVV $354, R12
	JMP  callbackasm1(SB)
	MOVV $355, R12
	JMP  callbackasm1(SB)
	MOVV $356, R12
	JMP  callbackasm1(SB)
	MOVV $357, R12
	JMP  callbackasm1(SB)
	MOVV $358, R12
	JMP  callbackasm1(SB)
	MOVV $359, R12
	JMP  callbackasm1(SB)
	MOVV $360, R12
	JMP  callbackasm1(SB)
	MOVV $361, R12
	JMP  callbackasm1(SB)
	MOVV $362, R12
	JMP  callbackasm1(SB)
	MOVV $363, R12
	JMP  callbackasm1(SB)
	MOVV $364, R12
	JMP  callbackasm1(SB)
	MOVV $365, R12
	JMP  callbackasm1(SB)
	MOVV $366, R12
	JMP  callbackasm1(SB)
	MOVV $367, R12
	JMP  callbackasm1(SB)
	MOVV $368, R12
	JMP  callbackasm1(SB)
	MOVV $369, R12
	JMP  callbackasm1(SB)
	MOVV $370, R12
	JMP  callbackasm1(SB)
	MOVV $371, R12
	JMP  callbackasm1(SB)
	MOVV $372, R12
	JMP  callbackasm1(SB)
	MOVV $373, R12
	JMP  callbackasm1(SB)
	MOVV $374, R12
	JMP  callbackasm1(SB)
	MOVV $375, R12
	JMP  callbackasm1(SB)
	MOVV $376, R12
	JMP  callbackasm1(SB)
	MOVV $377, R12
	JMP  callbackasm1(SB)
	MOVV $378, R12
	JMP  callbackasm1(SB)
	MOVV $379, R12
	JMP  callbackasm1(SB)
	MOVV $380, R12
	JMP  callbackasm1(SB)
	MOVV $381, R12
	JMP  callbackasm1(SB)
	MOVV $382, R12
	JMP  callbackasm1(SB)
	MOVV $383, R12
	JMP  callbackasm1(SB)
	MOVV $384, R12
	JMP  callbackasm1(SB)
	MOVV $385, R12
	JMP  callbackasm1(SB)
	MOVV $386, R12
	JMP  callbackasm1(SB)
	MOVV $387, R12
	JMP  callbackasm1(SB)
	MOVV $388, R12
	JMP  callbackasm1(SB)
	MOVV $389, R12
	JMP  callbackasm1(SB)
	MOVV $390, R12
	JMP  callbackasm1(SB)
	MOVV $391, R12
	JMP  callbackasm1(SB)
	MOVV $392, R12
	JMP  callbackasm1(SB)
	MOVV $393, R12
	JMP  callbackasm1(SB)
	MOVV $394, R12
	JMP  callbackasm1(SB)
	MOVV $395, R12
	JMP  callbackasm1(SB)
	MOVV $396, R12
	JMP  callbackasm1(SB)
	MOVV $397, R12
	JMP  callbackasm1(SB)
	MOVV $398, R12
	JMP  callbackasm1(SB)
	MOVV $399, R12
	JMP  callbackasm1(SB)
	MOVV $400, R12
	JMP  callbackasm1(SB)
	MOVV $401, R12
	JMP  callbackasm1(SB)
	MOVV $402, R12
	JMP  callbackasm1(SB)
	MOVV $403, R12
	JMP  callbackasm1(SB)
	MOVV $404, R12
	JMP  callbackasm1(SB)
	MOVV $405, R12
	JMP  callbackasm1(SB)
	MOVV $406, R12
	JMP  callbackasm1(SB)
	MOVV $407, R12
	JMP  callbackasm1(SB)
	MOVV $408, R12
	JMP  callbackasm1(SB)
	MOVV $409, R12
	JMP  callbackasm1(SB)
	MOVV $410, R12
	JMP  callbackasm1(SB)
	MOVV $411, R12
	JMP  callbackasm1(SB)
	MOVV $412, R12
	JMP  callbackasm1(SB)
	MOVV $413, R12
	JMP  callbackasm1(SB)
	MOVV $414, R12
	JMP  callbackasm1(SB)
	MOVV $415, R12
	JMP  callbackasm1(SB)
	MOVV $416, R12
	JMP  callbackasm1(SB)
	MOVV $417, R12
	JMP  callbackasm1(SB)
	MOVV $418, R12
	JMP  callbackasm1(SB)
	MOVV $419, R12
	JMP  callbackasm1(SB)
	MOVV $420, R12
	JMP  callbackasm1(SB)
	MOVV $421, R12
	JMP  callbackasm1(SB)
	MOVV $422, R12
	JMP  callbackasm1(SB)
	MOVV $423, R12
	JMP  callbackasm1(SB)
	MOVV $424, R12
	JMP  callbackasm1(SB)
	MOVV $425, R12
	JMP  callbackasm1(SB)
	MOVV $426, R12
	JMP  callbackasm1(SB)
	MOVV $427, R12
	JMP  callbackasm1(SB)
	MOVV $428, R12
	JMP  callbackasm1(SB)
	MOVV $429, R12
	JMP  callbackasm1(SB)
	MOVV $430, R12
	JMP  callbackasm1(SB)
	MOVV $431, R12
	JMP  callbackasm1(SB)
	MOVV $432, R12
	JMP  callbackasm1(SB)
	MOVV $433, R12
	JMP  callbackasm1(SB)
	MOVV $434, R12
	JMP  callbackasm1(SB)
	MOVV $435, R12
	JMP  callbackasm1(SB)
	MOVV $436, R12
	JMP  callbackasm1(SB)
	MOVV $437, R12
	JMP  callbackasm1(SB)
	MOVV $438, R12
	JMP  callbackasm1(SB)
	MOVV $439, R12
	JMP  callbackasm1(SB)
	MOVV $440, R12
	JMP  callbackasm1(SB)
	MOVV $441, R12
	JMP  callbackasm1(SB)
	MOVV $442, R12
	JMP  callbackasm1(SB)
	MOVV $443, R12
	JMP  callbackasm1(SB)
	MOVV $444, R12
	JMP  callbackasm1(SB)
	MOVV $445, R12
	JMP  callbackasm1(SB)
	MOVV $446, R12
	JMP  callbackasm1(SB)
	MOVV $447, R12
	JMP  callbackasm1(SB)
	MOVV $448, R12
	JMP  callbackasm1(SB)
	MOVV $449, R12
	JMP  callbackasm1(SB)
	MOVV $450, R12
	JMP  callbackasm1(SB)
	MOVV $451, R12
	JMP  callbackasm1(SB)
	MOVV $452, R12
	JMP  callbackasm1(SB)
	MOVV $453, R12
	JMP  callbackasm1(SB)
	MOVV $454, R12
	JMP  callbackasm1(SB)
	MOVV $455, R12
	JMP  callbackasm1(SB)
	MOVV $456, R12
	JMP  callbackasm1(SB)
	MOVV $457, R12
	JMP  callbackasm1(SB)
	MOVV $458, R12
	JMP  callbackasm1(SB)
	MOVV $459, R12
	JMP  callbackasm1(SB)
	MOVV $460, R12
	JMP  callbackasm1(SB)
	MOVV $461, R12
	JMP  callbackasm1(SB)
	MOVV $462, R12
	JMP  callbackasm1(SB)
	MOVV $463, R12
	JMP  callbackasm1(SB)
	MOVV $464, R12
	JMP  callbackasm1(SB)
	MOVV $465, R12
	JMP  callbackasm1(SB)
	MOVV $466, R12
	JMP  callbackasm1(SB)
	MOVV $467, R12
	JMP  callbackasm1(SB)
	MOVV $468, R12
	JMP  callbackasm1(SB)
	MOVV $469, R12
	JMP  callbackasm1(SB)
	MOVV $470, R12
	JMP  callbackasm1(SB)
	MOVV $471, R12
	JMP  callbackasm1(SB)
	MOVV $472, R12
	JMP  callbackasm1(SB)
	MOVV $473, R12
	JMP  callbackasm1(SB)
	MOVV $474, R12
	JMP  callbackasm1(SB)
	MOVV $475, R12
	JMP  callbackasm1(SB)
	MOVV $476, R12
	JMP  callbackasm1(SB)
	MOVV $477, R12
	JMP  callbackasm1(SB)
	MOVV $478, R12
	JMP  callbackasm1(SB)
	MOVV $479, R12
	JMP  callbackasm1(SB)
	MOVV $480, R12
	JMP  callbackasm1(SB)
	MOVV $481, R12
	JMP  callbackasm1(SB)
	MOVV $482, R12
	JMP  callbackasm1(SB)
	MOVV $483, R12
	JMP  callbackasm1(SB)
	MOVV $484, R12
	JMP  callbackasm1(SB)
	MOVV $485, R12
	JMP  callbackasm1(SB)
	MOVV $486, R12
	JMP  callbackasm1(SB)
	MOVV $487, R12
	JMP  callbackasm1(SB)
	MOVV $488, R12
	JMP  callbackasm1(SB)
	MOVV $489, R12
	JMP  callbackasm1(SB)
	MOVV $490, R12
	JMP  callbackasm1(SB)
	MOVV $491, R12
	JMP  callbackasm1(SB)
	MOVV $492, R12
	JMP  callbackasm1(SB)
	MOVV $493, R12
	JMP  callbackasm1(SB)
	MOVV $494, R12
	JMP  callbackasm1(SB)
	MOVV $495, R12
	JMP  callbackasm1(SB)
	MOVV $496, R12
	JMP  callbackasm1(SB)
	MOVV $497, R12
	JMP  callbackasm1(SB)
	MOVV $498, R12
	JMP  callbackasm1(SB)
	MOVV $499, R12
	JMP  callbackasm1(SB)
	MOVV $500, R12
	JMP  callbackasm1(SB)
	MOVV $501, R12
	JMP  callbackasm1(SB)
	MOVV $502, R12
	JMP  callbackasm1(SB)
	MOVV $503, R12
	JMP  callbackasm1(SB)
	MOVV $504, R12
	JMP  callbackasm1(SB)
	MOVV $505, R12
	JMP  callbackasm1(SB)
	MOVV $506, R12
	JMP  callbackasm1(SB)
	MOVV $507, R12
	JMP  callbackasm1(SB)
	MOVV $508, R12
	JMP  callbackasm1(SB)
	MOVV $509, R12
	JMP  callbackasm1(SB)
	MOVV $510, R12
	JMP  callbackasm1(SB)
	MOVV $511, R12
	JMP  callbackasm1(SB)
	MOVV $512, R12
	JMP  callbackasm1(SB)
	MOVV $513, R12
	JMP  callbackasm1(SB)
	MOVV $514, R12
	JMP  callbackasm1(SB)
	MOVV $515, R12
	JMP  callbackasm1(SB)
	MOVV $516, R12
	JMP  callbackasm1(SB)
	MOVV $517, R12
	JMP  callbackasm1(SB)
	MOVV $518, R12
	JMP  callbackasm1(SB)
	MOVV $519, R12
	JMP  callbackasm1(SB)
	MOVV $520, R12
	JMP  callbackasm1(SB)
	MOVV $521, R12
	JMP  callbackasm1(SB)
	MOVV $522, R12
	JMP  callbackasm1(SB)
	MOVV $523, R12
	JMP  callbackasm1(SB)
	MOVV $524, R12
	JMP  callbackasm1(SB)
	MOVV $525, R12
	JMP  callbackasm1(SB)
	MOVV $526, R12
	JMP  callbackasm1(SB)
	MOVV $527, R12
	JMP  callbackasm1(SB)
	MOVV $528, R12
	JMP  callbackasm1(SB)
	MOVV $529, R12
	JMP  callbackasm1(SB)
	MOVV $530, R12
	JMP  callbackasm1(SB)
	MOVV $531, R12
	JMP  callbackasm1(SB)
	MOVV $532, R12
	JMP  callbackasm1(SB)
	MOVV $533, R12
	JMP  callbackasm1(SB)
	MOVV $534, R12
	JMP  callbackasm1(SB)
	MOVV $535, R12
	JMP  callbackasm1(SB)
	MOVV $536, R12
	JMP  callbackasm1(SB)
	MOVV $537, R12
	JMP  callbackasm1(SB)
	MOVV $538, R12
	JMP  callbackasm1(SB)
	MOVV $539, R12
	JMP  callbackasm1(SB)
	MOVV $540, R12
	JMP  callbackasm1(SB)
	MOVV $541, R12
	JMP  callbackasm1(SB)
	MOVV $542, R12
	JMP  callbackasm1(SB)
	MOVV $543, R12
	JMP  callbackasm1(SB)
	MOVV $544, R12
	JMP  callbackasm1(SB)
	MOVV $545, R12
	JMP  callbackasm1(SB)
	MOVV $546, R12
	JMP  callbackasm1(SB)
	MOVV $547, R12
	JMP  callbackasm1(SB)
	MOVV $548, R12
	JMP  callbackasm1(SB)
	MOVV $549, R12
	JMP  callbackasm1(SB)
	MOVV $550, R12
	JMP  callbackasm1(SB)
	MOVV $551, R12
	JMP  callbackasm1(SB)
	MOVV $552, R12
	JMP  callbackasm1(SB)
	MOVV $553, R12
	JMP  callbackasm1(SB)
	MOVV $554, R12
	JMP  callbackasm1(SB)
	MOVV $555, R12
	JMP  callbackasm1(SB)
	MOVV $556, R12
	JMP  callbackasm1(SB)
	MOVV $557, R12
	JMP  callbackasm1(SB)
	MOVV $558, R12
	JMP  callbackasm1(SB)
	MOVV $559, R12
	JMP  callbackasm1(SB)
	MOVV $560, R12
	JMP  callbackasm1(SB)
	MOVV $561, R12
	JMP  callbackasm1(SB)
	MOVV $562, R12
	JMP  callbackasm1(SB)
	MOVV $563, R12
	JMP  callbackasm1(SB)
	MOVV $564, R12
	JMP  callbackasm1(SB)
	MOVV $565, R12
	JMP  callbackasm1(SB)
	MOVV $566, R12
	JMP  callbackasm1(SB)
	MOVV $567, R12
	JMP  callbackasm1(SB)
	MOVV $568, R12
	JMP  callbackasm1(SB)
	MOVV $569, R12
	JMP  callbackasm1(SB)
	MOVV $570, R12
	JMP  callbackasm1(SB)
	MOVV $571, R12
	JMP  callbackasm1(SB)
	MOVV $572, R12
	JMP  callbackasm1(SB)
	MOVV $573, R12
	JMP  callbackasm1(SB)
	MOVV $574, R12
	JMP  callbackasm1(SB)
	MOVV $575, R12
	JMP  callbackasm1(SB)
	MOVV $576, R12
	JMP  callbackasm1(SB)
	MOVV $577, R12
	JMP  callbackasm1(SB)
	MOVV $578, R12
	JMP  callbackasm1(SB)
	MOVV $579, R12
	JMP  callbackasm1(SB)
	MOVV $580, R12
	JMP  callbackasm1(SB)
	MOVV $581, R12
	JMP  callbackasm1(SB)
	MOVV $582, R12
	JMP  callbackasm1(SB)
	MOVV $583, R12
	JMP  callbackasm1(SB)
	MOVV $584, R12
	JMP  callbackasm1(SB)
	MOVV $585, R12
	JMP  callbackasm1(SB)
	MOVV $586, R12
	JMP  callbackasm1(SB)
	MOVV $587, R12
	JMP  callbackasm1(SB)
	MOVV $588, R12
	JMP  callbackasm1(SB)
	MOVV $589, R12
	JMP  callbackasm1(SB)
	MOVV $590, R12
	JMP  callbackasm1(SB)
	MOVV $591, R12
	JMP  callbackasm1(SB)
	MOVV $592, R12
	JMP  callbackasm1(SB)
	MOVV $593, R12
	JMP  callbackasm1(SB)
	MOVV $594, R12
	JMP  callbackasm1(SB)
	MOVV $595, R12
	JMP  callbackasm1(SB)
	MOVV $596, R12
	JMP  callbackasm1(SB)
	MOVV $597, R12
	JMP  callbackasm1(SB)
	MOVV $598, R12
	JMP  callbackasm1(SB)
	MOVV $599, R12
	JMP  callbackasm1(SB)
	MOVV $600, R12
	JMP  callbackasm1(SB)
	MOVV $601, R12
	JMP  callbackasm1(SB)
	MOVV $602, R12
	JMP  callbackasm1(SB)
	MOVV $603, R12
	JMP  callbackasm1(SB)
	MOVV $604, R12
	JMP  callbackasm1(SB)
	MOVV $605, R12
	JMP  callbackasm1(SB)
	MOVV $606, R12
	JMP  callbackasm1(SB)
	MOVV $607, R12
	JMP  callbackasm1(SB)
	MOVV $608, R12
	JMP  callbackasm1(SB)
	MOVV $609, R12
	JMP  callbackasm1(SB)
	MOVV $610, R12
	JMP  callbackasm1(SB)
	MOVV $611, R12
	JMP  callbackasm1(SB)
	MOVV $612, R12
	JMP  callbackasm1(SB)
	MOVV $613, R12
	JMP  callbackasm1(SB)
	MOVV $614, R12
	JMP  callbackasm1(SB)
	MOVV $615, R12
	JMP  callbackasm1(SB)
	MOVV $616, R12
	JMP  callbackasm1(SB)
	MOVV $617, R12
	JMP  callbackasm1(SB)
	MOVV $618, R12
	JMP  callbackasm1(SB)
	MOVV $619, R12
	JMP  callbackasm1(SB)
	MOVV $620, R12
	JMP  callbackasm1(SB)
	MOVV $621, R12
	JMP  callbackasm1(SB)
	MOVV $622, R12
	JMP  callbackasm1(SB)
	MOVV $623, R12
	JMP  callbackasm1(SB)
	MOVV $624, R12
	JMP  callbackasm1(SB)
	MOVV $625, R12
	JMP  callbackasm1(SB)
	MOVV $626, R12
	JMP  callbackasm1(SB)
	MOVV $627, R12
	JMP  callbackasm1(SB)
	MOVV $628, R12
	JMP  callbackasm1(SB)
	MOVV $629, R12
	JMP  callbackasm1(SB)
	MOVV $630, R12
	JMP  callbackasm1(SB)
	MOVV $631, R12
	JMP  callbackasm1(SB)
	MOVV $632, R12
	JMP  callbackasm1(SB)
	MOVV $633, R12
	JMP  callbackasm1(SB)
	MOVV $634, R12
	JMP  callbackasm1(SB)
	MOVV $635, R12
	JMP  callbackasm1(SB)
	MOVV $636, R12
	JMP  callbackasm1(SB)
	MOVV $637, R12
	JMP  callbackasm1(SB)
	MOVV $638, R12
	JMP  callbackasm1(SB)
	MOVV $639, R12
	JMP  callbackasm1(SB)
	MOVV $640, R12
	JMP  callbackasm1(SB)
	MOVV $641, R12
	JMP  callbackasm1(SB)
	MOVV $642, R12
	JMP  callbackasm1(SB)
	MOVV $643, R12
	JMP  callbackasm1(SB)
	MOVV $644, R12
	JMP  callbackasm1(SB)
	MOVV $645, R12
	JMP  callbackasm1(SB)
	MOVV $646, R12
	JMP  callbackasm1(SB)
	MOVV $647, R12
	JMP  callbackasm1(SB)
	MOVV $648, R12
	JMP  callbackasm1(SB)
	MOVV $649, R12
	JMP  callbackasm1(SB)
	MOVV $650, R12
	JMP  callbackasm1(SB)
	MOVV $651, R12
	JMP  callbackasm1(SB)
	MOVV $652, R12
	JMP  callbackasm1(SB)
	MOVV $653, R12
	JMP  callbackasm1(SB)
	MOVV $654, R12
	JMP  callbackasm1(SB)
	MOVV $655, R12
	JMP  callbackasm1(SB)
	MOVV $656, R12
	JMP  callbackasm1(SB)
	MOVV $657, R12
	JMP  callbackasm1(SB)
	MOVV $658, R12
	JMP  callbackasm1(SB)
	MOVV $659, R12
	JMP  callbackasm1(SB)
	MOVV $660, R12
	JMP  callbackasm1(SB)
	MOVV $661, R12
	JMP  callbackasm1(SB)
	MOVV $662, R12
	JMP  callbackasm1(SB)
	MOVV $663, R12
	JMP  callbackasm1(SB)
	MOVV $664, R12
	JMP  callbackasm1(SB)
	MOVV $665, R12
	JMP  callbackasm1(SB)
	MOVV $666, R12
	JMP  callbackasm1(SB)
	MOVV $667, R12
	JMP  callbackasm1(SB)
	MOVV $668, R12
	JMP  callbackasm1(SB)
	MOVV $669, R12
	JMP  callbackasm1(SB)
	MOVV $670, R12
	JMP  callbackasm1(SB)
	MOVV $671, R12
	JMP  callbackasm1(SB)
	MOVV $672, R12
	JMP  callbackasm1(SB)
	MOVV $673, R12
	JMP  callbackasm1(SB)
	MOVV $674, R12
	JMP  callbackasm1(SB)
	MOVV $675, R12
	JMP  callbackasm1(SB)
	MOVV $676, R12
	JMP  callbackasm1(SB)
	MOVV $677, R12
	JMP  callbackasm1(SB)
	MOVV $678, R12
	JMP  callbackasm1(SB)
	MOVV $679, R12
	JMP  callbackasm1(SB)
	MOVV $680, R12
	JMP  callbackasm1(SB)
	MOVV $681, R12
	JMP  callbackasm1(SB)
	MOVV $682, R12
	JMP  callbackasm1(SB)
	MOVV $683, R12
	JMP  callbackasm1(SB)
	MOVV $684, R12
	JMP  callbackasm1(SB)
	MOVV $685, R12
	JMP  callbackasm1(SB)
	MOVV $686, R12
	JMP  callbackasm1(SB)
	MOVV $687, R12
	JMP  callbackasm1(SB)
	MOVV $688, R12
	JMP  callbackasm1(SB)
	MOVV $689, R12
	JMP  callbackasm1(SB)
	MOVV $690, R12
	JMP  callbackasm1(SB)
	MOVV $691, R12
	JMP  callbackasm1(SB)
	MOVV $692, R12
	JMP  callbackasm1(SB)
	MOVV $693, R12
	JMP  callbackasm1(SB)
	MOVV $694, R12
	JMP  callbackasm1(SB)
	MOVV $695, R12
	JMP  callbackasm1(SB)
	MOVV $696, R12
	JMP  callbackasm1(SB)
	MOVV $697, R12
	JMP  callbackasm1(SB)
	MOVV $698, R12
	JMP  callbackasm1(SB)
	MOVV $699, R12
	JMP  callbackasm1(SB)
	MOVV $700, R12
	JMP  callbackasm1(SB)
	MOVV $701, R12
	JMP  callbackasm1(SB)
	MOVV $702, R12
	JMP  callbackasm1(SB)
	MOVV $703, R12
	JMP  callbackasm1(SB)
	MOVV $704, R12
	JMP  callbackasm1(SB)
	MOVV $705, R12
	JMP  callbackasm1(SB)
	MOVV $706, R12
	JMP  callbackasm1(SB)
	MOVV $707, R12
	JMP  callbackasm1(SB)
	MOVV $708, R12
	JMP  callbackasm1(SB)
	MOVV $709, R12
	JMP  callbackasm1(SB)
	MOVV $710, R12
	JMP  callbackasm1(SB)
	MOVV $711, R12
	JMP  callbackasm1(SB)
	MOVV $712, R12
	JMP  callbackasm1(SB)
	MOVV $713, R12
	JMP  callbackasm1(SB)
	MOVV $714, R12
	JMP  callbackasm1(SB)
	MOVV $715, R12
	JMP  callbackasm1(SB)
	MOVV $716, R12
	JMP  callbackasm1(SB)
	MOVV $717, R12
	JMP  callbackasm1(SB)
	MOVV $718, R12
	JMP  callbackasm1(SB)
	MOVV $719, R12
	JMP  callbackasm1(SB)
	MOVV $720, R12
	JMP  callbackasm1(SB)
	MOVV $721, R12
	JMP  callbackasm1(SB)
	MOVV $722, R12
	JMP  callbackasm1(SB)
	MOVV $723, R12
	JMP  callbackasm1(SB)
	MOVV $724, R12
	JMP  callbackasm1(SB)
	MOVV $725, R12
	JMP  callbackasm1(SB)
	MOVV $726, R12
	JMP  callbackasm1(SB)
	MOVV $727, R12
	JMP  callbackasm1(SB)
	MOVV $728, R12
	JMP  callbackasm1(SB)
	MOVV $729, R12
	JMP  callbackasm1(SB)
	MOVV $730, R12
	JMP  callbackasm1(SB)
	MOVV $731, R12
	JMP  callbackasm1(SB)
	MOVV $732, R12
	JMP  callbackasm1(SB)
	MOVV $733, R12
	JMP  callbackasm1(SB)
	MOVV $734, R12
	JMP  callbackasm1(SB)
	MOVV $735, R12
	JMP  callbackasm1(SB)
	MOVV $736, R12
	JMP  callbackasm1(SB)
	MOVV $737, R12
	JMP  callbackasm1(SB)
	MOVV $738, R12
	JMP  callbackasm1(SB)
	MOVV $739, R12
	JMP  callbackasm1(SB)
	MOVV $740, R12
	JMP  callbackasm1(SB)
	MOVV $741, R12
	JMP  callbackasm1(SB)
	MOVV $742, R12
	JMP  callbackasm1(SB)
	MOVV $743, R12
	JMP  callbackasm1(SB)
	MOVV $744, R12
	JMP  callbackasm1(SB)
	MOVV $745, R12
	JMP  callbackasm1(SB)
	MOVV $746, R12
	JMP  callbackasm1(SB)
	MOVV $747, R12
	JMP  callbackasm1(SB)
	MOVV $748, R12
	JMP  callbackasm1(SB)
	MOVV $749, R12
	JMP  callbackasm1(SB)
	MOVV $750, R12
	JMP  callbackasm1(SB)
	MOVV $751, R12
	JMP  callbackasm1(SB)
	MOVV $752, R12
	JMP  callbackasm1(SB)
	MOVV $753, R12
	JMP  callbackasm1(SB)
	MOVV $754, R12
	JMP  callbackasm1(SB)
	MOVV $755, R12
	JMP  callbackasm1(SB)
	MOVV $756, R12
	JMP  callbackasm1(SB)
	MOVV $757, R12
	JMP  callbackasm1(SB)
	MOVV $758, R12
	JMP  callbackasm1(SB)
	MOVV $759, R12
	JMP  callbackasm1(SB)
	MOVV $760, R12
	JMP  callbackasm1(SB)
	MOVV $761, R12
	JMP  callbackasm1(SB)
	MOVV $762, R12
	JMP  callbackasm1(SB)
	MOVV $763, R12
	JMP  callbackasm1(SB)
	MOVV $764, R12
	JMP  callbackasm1(SB)
	MOVV $765, R12
	JMP  callbackasm1(SB)
	MOVV $766, R12
	JMP  callbackasm1(SB)
	MOVV $767, R12
	JMP  callbackasm1(SB)
	MOVV $768, R12
	JMP  callbackasm1(SB)
	MOVV $769, R12
	JMP  callbackasm1(SB)
	MOVV $770, R12
	JMP  callbackasm1(SB)
	MOVV $771, R12
	JMP  callbackasm1(SB)
	MOVV $772, R12
	JMP  callbackasm1(SB)
	MOVV $773, R12
	JMP  callbackasm1(SB)
	MOVV $774, R12
	JMP  callbackasm1(SB)
	MOVV $775, R12
	JMP  callbackasm1(SB)
	MOVV $776, R12
	JMP  callbackasm1(SB)
	MOVV $777, R12
	JMP  callbackasm1(SB)
	MOVV $778, R12
	JMP  callbackasm1(SB)
	MOVV $779, R12
	JMP  callbackasm1(SB)
	MOVV $780, R12
	JMP  callbackasm1(SB)
	MOVV $781, R12
	JMP  callbackasm1(SB)
	MOVV $782, R12
	JMP  callbackasm1(SB)
	MOVV $783, R12
	JMP  callbackasm1(SB)
	MOVV $784, R12
	JMP  callbackasm1(SB)
	MOVV $785, R12
	JMP  callbackasm1(SB)
	MOVV $786, R12
	JMP  callbackasm1(SB)
	MOVV $787, R12
	JMP  callbackasm1(SB)
	MOVV $788, R12
	JMP  callbackasm1(SB)
	MOVV $789, R12
	JMP  callbackasm1(SB)
	MOVV $790, R12
	JMP  callbackasm1(SB)
	MOVV $791, R12
	JMP  callbackasm1(SB)
	MOVV $792, R12
	JMP  callbackasm1(SB)
	MOVV $793, R12
	JMP  callbackasm1(SB)
	MOVV $794, R12
	JMP  callbackasm1(SB)
	MOVV $795, R12
	JMP  callbackasm1(SB)
	MOVV $796, R12
	JMP  callbackasm1(SB)
	MOVV $797, R12
	JMP  callbackasm1(SB)
	MOVV $798, R12
	JMP  callbackasm1(SB)
	MOVV $799, R12
	JMP  callbackasm1(SB)
	MOVV $800, R12
	JMP  callbackasm1(SB)
	MOVV $801, R12
	JMP  callbackasm1(SB)
	MOVV $802, R12
	JMP  callbackasm1(SB)
	MOVV $803, R12
	JMP  callbackasm1(SB)
	MOVV $804, R12
	JMP  callbackasm1(SB)
	MOVV $805, R12
	JMP  callbackasm1(SB)
	MOVV $806, R12
	JMP  callbackasm1(SB)
	MOVV $807, R12
	JMP  callbackasm1(SB)
	MOVV $808, R12
	JMP  callbackasm1(SB)
	MOVV $809, R12
	JMP  callbackasm1(SB)
	MOVV $810, R12
	JMP  callbackasm1(SB)
	MOVV $811, R12
	JMP  callbackasm1(SB)
	MOVV $812, R12
	JMP  callbackasm1(SB)
	MOVV $813, R12
	JMP  callbackasm1(SB)
	MOVV $814, R12
	JMP  callbackasm1(SB)
	MOVV $815, R12
	JMP  callbackasm1(SB)
	MOVV $816, R12
	JMP  callbackasm1(SB)
	MOVV $817, R12
	JMP  callbackasm1(SB)
	MOVV $818, R12
	JMP  callbackasm1(SB)
	MOVV $819, R12
	JMP  callbackasm1(SB)
	MOVV $820, R12
	JMP  callbackasm1(SB)
	MOVV $821, R12
	JMP  callbackasm1(SB)
	MOVV $822, R12
	JMP  callbackasm1(SB)
	MOVV $823, R12
	JMP  callbackasm1(SB)
	MOVV $824, R12
	JMP  callbackasm1(SB)
	MOVV $825, R12
	JMP  callbackasm1(SB)
	MOVV $826, R12
	JMP  callbackasm1(SB)
	MOVV $827, R12
	JMP  callbackasm1(SB)
	MOVV $828, R12
	JMP  callbackasm1(SB)
	MOVV $829, R12
	JMP  callbackasm1(SB)
	MOVV $830, R12
	JMP  callbackasm1(SB)
	MOVV $831, R12
	JMP  callbackasm1(SB)
	MOVV $832, R12
	JMP  callbackasm1(SB)
	MOVV $833, R12
	JMP  callbackasm1(SB)
	MOVV $834, R12
	JMP  callbackasm1(SB)
	MOVV $835, R12
	JMP  callbackasm1(SB)
	MOVV $836, R12
	JMP  callbackasm1(SB)
	MOVV $837, R12
	JMP  callbackasm1(SB)
	MOVV $838, R12
	JMP  callbackasm1(SB)
	MOVV $839, R12
	JMP  callbackasm1(SB)
	MOVV $840, R12
	JMP  callbackasm1(SB)
	MOVV $841, R12
	JMP  callbackasm1(SB)
	MOVV $842, R12
	JMP  callbackasm1(SB)
	MOVV $843, R12
	JMP  callbackasm1(SB)
	MOVV $844, R12
	JMP  callbackasm1(SB)
	MOVV $845, R12
	JMP  callbackasm1(SB)
	MOVV $846, R12
	JMP  callbackasm1(SB)
	MOVV $847, R12
	JMP  callbackasm1(SB)
	MOVV $848, R12
	JMP  callbackasm1(SB)
	MOVV $849, R12
	JMP  callbackasm1(SB)
	MOVV $850, R12
	JMP  callbackasm1(SB)
	MOVV $851, R12
	JMP  callbackasm1(SB)
	MOVV $852, R12
	JMP  callbackasm1(SB)
	MOVV $853, R12
	JMP  callbackasm1(SB)
	MOVV $854, R12
	JMP  callbackasm1(SB)
	MOVV $855, R12
	JMP  callbackasm1(SB)
	MOVV $856, R12
	JMP  callbackasm1(SB)
	MOVV $857, R12
	JMP  callbackasm1(SB)
	MOVV $858, R12
	JMP  callbackasm1(SB)
	MOVV $859, R12
	JMP  callbackasm1(SB)
	MOVV $860, R12
	JMP  callbackasm1(SB)
	MOVV $861, R12
	JMP  callbackasm1(SB)
	MOVV $862, R12
	JMP  callbackasm1(SB)
	MOVV $863, R12
	JMP  callbackasm1(SB)
	MOVV $864, R12
	JMP  callbackasm1(SB)
	MOVV $865, R12
	JMP  callbackasm1(SB)
	MOVV $866, R12
	JMP  callbackasm1(SB)
	MOVV $867, R12
	JMP  callbackasm1(SB)
	MOVV $868, R12
	JMP  callbackasm1(SB)
	MOVV $869, R12
	JMP  callbackasm1(SB)
	MOVV $870, R12
	JMP  callbackasm1(SB)
	MOVV $871, R12
	JMP  callbackasm1(SB)
	MOVV $872, R12
	JMP  callbackasm1(SB)
	MOVV $873, R12
	JMP  callbackasm1(SB)
	MOVV $874, R12
	JMP  callbackasm1(SB)
	MOVV $875, R12
	JMP  callbackasm1(SB)
	MOVV $876, R12
	JMP  callbackasm1(SB)
	MOVV $877, R12
	JMP  callbackasm1(SB)
	MOVV $878, R12
	JMP  callbackasm1(SB)
	MOVV $879, R12
	JMP  callbackasm1(SB)
	MOVV $880, R12
	JMP  callbackasm1(SB)
	MOVV $881, R12
	JMP  callbackasm1(SB)
	MOVV $882, R12
	JMP  callbackasm1(SB)
	MOVV $883, R12
	JMP  callbackasm1(SB)
	MOVV $884, R12
	JMP  callbackasm1(SB)
	MOVV $885, R12
	JMP  callbackasm1(SB)
	MOVV $886, R12
	JMP  callbackasm1(SB)
	MOVV $887, R12
	JMP  callbackasm1(SB)
	MOVV $888, R12
	JMP  callbackasm1(SB)
	MOVV $889, R12
	JMP  callbackasm1(SB)
	MOVV $890, R12
	JMP  callbackasm1(SB)
	MOVV $891, R12
	JMP  callbackasm1(SB)
	MOVV $892, R12
	JMP  callbackasm1(SB)
	MOVV $893, R12
	JMP  callbackasm1(SB)
	MOVV $894, R12
	JMP  callbackasm1(SB)
	MOVV $895, R12
	JMP  callbackasm1(SB)
	MOVV $896, R12
	JMP  callbackasm1(SB)
	MOVV $897, R12
	JMP  callbackasm1(SB)
	MOVV $898, R12
	JMP  callbackasm1(SB)
	MOVV $899, R12
	JMP  callbackasm1(SB)
	MOVV $900, R12
	JMP  callbackasm1(SB)
	MOVV $901, R12
	JMP  callbackasm1(SB)
	MOVV $902, R12
	JMP  callbackasm1(SB)
	MOVV $903, R12
	JMP  callbackasm1(SB)
	MOVV $904, R12
	JMP  callbackasm1(SB)
	MOVV $905, R12
	JMP  callbackasm1(SB)
	MOVV $906, R12
	JMP  callbackasm1(SB)
	MOVV $907, R12
	JMP  callbackasm1(SB)
	MOVV $908, R12
	JMP  callbackasm1(SB)
	MOVV $909, R12
	JMP  callbackasm1(SB)
	MOVV $910, R12
	JMP  callbackasm1(SB)
	MOVV $911, R12
	JMP  callbackasm1(SB)
	MOVV $912, R12
	JMP  callbackasm1(SB)
	MOVV $913, R12
	JMP  callbackasm1(SB)
	MOVV $914, R12
	JMP  callbackasm1(SB)
	MOVV $915, R12
	JMP  callbackasm1(SB)
	MOVV $916, R12
	JMP  callbackasm1(SB)
	MOVV $917, R12
	JMP  callbackasm1(SB)
	MOVV $918, R12
	JMP  callbackasm1(SB)
	MOVV $919, R12
	JMP  callbackasm1(SB)
	MOVV $920, R12
	JMP  callbackasm1(SB)
	MOVV $921, R12
	JMP  callbackasm1(SB)
	MOVV $922, R12
	JMP  callbackasm1(SB)
	MOVV $923, R12
	JMP  callbackasm1(SB)
	MOVV $924, R12
	JMP  callbackasm1(SB)
	MOVV $925, R12
	JMP  callbackasm1(SB)
	MOVV $926, R12
	JMP  callbackasm1(SB)
	MOVV $927, R12
	JMP  callbackasm1(SB)
	MOVV $928, R12
	JMP  callbackasm1(SB)
	MOVV $929, R12
	JMP  callbackasm1(SB)
	MOVV $930, R12
	JMP  callbackasm1(SB)
	MOVV $931, R12
	JMP  callbackasm1(SB)
	MOVV $932, R12
	JMP  callbackasm1(SB)
	MOVV $933, R12
	JMP  callbackasm1(SB)
	MOVV $934, R12
	JMP  callbackasm1(SB)
	MOVV $935, R12
	JMP  callbackasm1(SB)
	MOVV $936, R12
	JMP  callbackasm1(SB)
	MOVV $937, R12
	JMP  callbackasm1(SB)
	MOVV $938, R12
	JMP  callbackasm1(SB)
	MOVV $939, R12
	JMP  callbackasm1(SB)
	MOVV $940, R12
	JMP  callbackasm1(SB)
	MOVV $941, R12
	JMP  callbackasm1(SB)
	MOVV $942, R12
	JMP  callbackasm1(SB)
	MOVV $943, R12
	JMP  callbackasm1(SB)
	MOVV $944, R12
	JMP  callbackasm1(SB)
	MOVV $945, R12
	JMP  callbackasm1(SB)
	MOVV $946, R12
	JMP  callbackasm1(SB)
	MOVV $947, R12
	JMP  callbackasm1(SB)
	MOVV $948, R12
	JMP  callbackasm1(SB)
	MOVV $949, R12
	JMP  callbackasm1(SB)
	MOVV $950, R12
	JMP  callbackasm1(SB)
	MOVV $951, R12
	JMP  callbackasm1(SB)
	MOVV $952, R12
	JMP  callbackasm1(SB)
	MOVV $953, R12
	JMP  callbackasm1(SB)
	MOVV $954, R12
	JMP  callbackasm1(SB)
	MOVV $955, R12
	JMP  callbackasm1(SB)
	MOVV $956, R12
	JMP  callbackasm1(SB)
	MOVV $957, R12
	JMP  callbackasm1(SB)
	MOVV $958, R12
	JMP  callbackasm1(SB)
	MOVV $959, R12
	JMP  callbackasm1(SB)
	MOVV $960, R12
	JMP  callbackasm1(SB)
	MOVV $961, R12
	JMP  callbackasm1(SB)
	MOVV $962, R12
	JMP  callbackasm1(SB)
	MOVV $963, R12
	JMP  callbackasm1(SB)
	MOVV $964, R12
	JMP  callbackasm1(SB)
	MOVV $965, R12
	JMP  callbackasm1(SB)
	MOVV $966, R12
	JMP  callbackasm1(SB)
	MOVV $967, R12
	JMP  callbackasm1(SB)
	MOVV $968, R12
	JMP  callbackasm1(SB)
	MOVV $969, R12
	JMP  callbackasm1(SB)
	MOVV $970, R12
	JMP  callbackasm1(SB)
	MOVV $971, R12
	JMP  callbackasm1(SB)
	MOVV $972, R12
	JMP  callbackasm1(SB)
	MOVV $973, R12
	JMP  callbackasm1(SB)
	MOVV $974, R12
	JMP  callbackasm1(SB)
	MOVV $975, R12
	JMP  callbackasm1(SB)
	MOVV $976, R12
	JMP  callbackasm1(SB)
	MOVV $977, R12
	JMP  callbackasm1(SB)
	MOVV $978, R12
	JMP  callbackasm1(SB)
	MOVV $979, R12
	JMP  callbackasm1(SB)
	MOVV $980, R12
	JMP  callbackasm1(SB)
	MOVV $981, R12
	JMP  callbackasm1(SB)
	MOVV $982, R12
	JMP  callbackasm1(SB)
	MOVV $983, R12
	JMP  callbackasm1(SB)
	MOVV $984, R12
	JMP  callbackasm1(SB)
	MOVV $985, R12
	JMP  callbackasm1(SB)
	MOVV $986, R12
	JMP  callbackasm1(SB)
	MOVV $987, R12
	JMP  callbackasm1(SB)
	MOVV $988, R12
	JMP  callbackasm1(SB)
	MOVV $989, R12
	JMP  callbackasm1(SB)
	MOVV $990, R12
	JMP  callbackasm1(SB)
	MOVV $991, R12
	JMP  callbackasm1(SB)
	MOVV $992, R12
	JMP  callbackasm1(SB)
	MOVV $993, R12
	JMP  callbackasm1(SB)
	MOVV $994, R12
	JMP  callbackasm1(SB)
	MOVV $995, R12
	JMP  callbackasm1(SB)
	MOVV $996, R12
	JMP  callbackasm1(SB)
	MOVV $997, R12
	JMP  callbackasm1(SB)
	MOVV $998, R12
	JMP  callbackasm1(SB)
	MOVV $999, R12
	JMP  callbackasm1(SB)
	MOVV $1000, R12
	JMP  callbackasm1(SB)
	MOVV $1001, R12
	JMP  callbackasm1(SB)
	MOVV $1002, R12
	JMP  callbackasm1(SB)
	MOVV $1003, R12
	JMP  callbackasm1(SB)
	MOVV $1004, R12
	JMP  callbackasm1(SB)
	MOVV $1005, R12
	JMP  callbackasm1(SB)
	MOVV $1006, R12
	JMP  callbackasm1(SB)
	MOVV $1007, R12
	JMP  callbackasm1(SB)
	MOVV $1008, R12
	JMP  callbackasm1(SB)
	MOVV $1009, R12
	JMP  callbackasm1(SB)
	MOVV $1010, R12
	JMP  callbackasm1(SB)
	MOVV $1011, R12
	JMP  callbackasm1(SB)
	MOVV $1012, R12
	JMP  callbackasm1(SB)
	MOVV $1013, R12
	JMP  callbackasm1(SB)
	MOVV $1014, R12
	JMP  callbackasm1(SB)
	MOVV $1015, R12
	JMP  callbackasm1(SB)
	MOVV $1016, R12
	JMP  callbackasm1(SB)
	MOVV $1017, R12
	JMP  callbackasm1(SB)
	MOVV $1018, R12
	JMP  callbackasm1(SB)
	MOVV $1019, R12
	JMP  callbackasm1(SB)
	MOVV $1020, R12
	JMP  callbackasm1(SB)
	MOVV $1021, R12
	JMP  callbackasm1(SB)
	MOVV $1022, R12
	JMP  callbackasm1(SB)
	MOVV $1023, R12
	JMP  callbackasm1(SB)
	MOVV $1024, R12
	JMP  callbackasm1(SB)
	MOVV $1025, R12
	JMP  callbackasm1(SB)
	MOVV $1026, R12
	JMP  callbackasm1(SB)
	MOVV $1027, R12
	JMP  callbackasm1(SB)
	MOVV $1028, R12
	JMP  callbackasm1(SB)
	MOVV $1029, R12
	JMP  callbackasm1(SB)
	MOVV $1030, R12
	JMP  callbackasm1(SB)
	MOVV $1031, R12
	JMP  callbackasm1(SB)
	MOVV $1032, R12
	JMP  callbackasm1(SB)
	MOVV $1033, R12
	JMP  callbackasm1(SB)
	MOVV $1034, R12
	JMP  callbackasm1(SB)
	MOVV $1035, R12
	JMP  callbackasm1(SB)
	MOVV $1036, R12
	JMP  callbackasm1(SB)
	MOVV $1037, R12
	JMP  callbackasm1(SB)
	MOVV $1038, R12
	JMP  callbackasm1(SB)
	MOVV $1039, R12
	JMP  callbackasm1(SB)
	MOVV $1040, R12
	JMP  callbackasm1(SB)
	MOVV $1041, R12
	JMP  callbackasm1(SB)
	MOVV $1042, R12
	JMP  callbackasm1(SB)
	MOVV $1043, R12
	JMP  callbackasm1(SB)
	MOVV $1044, R12
	JMP  callbackasm1(SB)
	MOVV $1045, R12
	JMP  callbackasm1(SB)
	MOVV $1046, R12
	JMP  callbackasm1(SB)
	MOVV $1047, R12
	JMP  callbackasm1(SB)
	MOVV $1048, R12
	JMP  callbackasm1(SB)
	MOVV $1049, R12
	JMP  callbackasm1(SB)
	MOVV $1050, R12
	JMP  callbackasm1(SB)
	MOVV $1051, R12
	JMP  callbackasm1(SB)
	MOVV $1052, R12
	JMP  callbackasm1(SB)
	MOVV $1053, R12
	JMP  callbackasm1(SB)
	MOVV $1054, R12
	JMP  callbackasm1(SB)
	MOVV $1055, R12
	JMP  callbackasm1(SB)
	MOVV $1056, R12
	JMP  callbackasm1(SB)
	MOVV $1057, R12
	JMP  callbackasm1(SB)
	MOVV $1058, R12
	JMP  callbackasm1(SB)
	MOVV $1059, R12
	JMP  callbackasm1(SB)
	MOVV $1060, R12
	JMP  callbackasm1(SB)
	MOVV $1061, R12
	JMP  callbackasm1(SB)
	MOVV $1062, R12
	JMP  callbackasm1(SB)
	MOVV $1063, R12
	JMP  callbackasm1(SB)
	MOVV $1064, R12
	JMP  callbackasm1(SB)
	MOVV $1065, R12
	JMP  callbackasm1(SB)
	MOVV $1066, R12
	JMP  callbackasm1(SB)
	MOVV $1067, R12
	JMP  callbackasm1(SB)
	MOVV $1068, R12
	JMP  callbackasm1(SB)
	MOVV $1069, R12
	JMP  callbackasm1(SB)
	MOVV $1070, R12
	JMP  callbackasm1(SB)
	MOVV $1071, R12
	JMP  callbackasm1(SB)
	MOVV $1072, R12
	JMP  callbackasm1(SB)
	MOVV $1073, R12
	JMP  callbackasm1(SB)
	MOVV $1074, R12
	JMP  callbackasm1(SB)
	MOVV $1075, R12
	JMP  callbackasm1(SB)
	MOVV $1076, R12
	JMP  callbackasm1(SB)
	MOVV $1077, R12
	JMP  callbackasm1(SB)
	MOVV $1078, R12
	JMP  callbackasm1(SB)
	MOVV $1079, R12
	JMP  callbackasm1(SB)
	MOVV $1080, R12
	JMP  callbackasm1(SB)
	MOVV $1081, R12
	JMP  callbackasm1(SB)
	MOVV $1082, R12
	JMP  callbackasm1(SB)
	MOVV $1083, R12
	JMP  callbackasm1(SB)
	MOVV $1084, R12
	JMP  callbackasm1(SB)
	MOVV $1085, R12
	JMP  callbackasm1(SB)
	MOVV $1086, R12
	JMP  callbackasm1(SB)
	MOVV $1087, R12
	JMP  callbackasm1(SB)
	MOVV $1088, R12
	JMP  callbackasm1(SB)
	MOVV $1089, R12
	JMP  callbackasm1(SB)
	MOVV $1090, R12
	JMP  callbackasm1(SB)
	MOVV $1091, R12
	JMP  callbackasm1(SB)
	MOVV $1092, R12
	JMP  callbackasm1(SB)
	MOVV $1093, R12
	JMP  callbackasm1(SB)
	MOVV $1094, R12
	JMP  callbackasm1(SB)
	MOVV $1095, R12
	JMP  callbackasm1(SB)
	MOVV $1096, R12
	JMP  callbackasm1(SB)
	MOVV $1097, R12
	JMP  callbackasm1(SB)
	MOVV $1098, R12
	JMP  callbackasm1(SB)
	MOVV $1099, R12
	JMP  callbackasm1(SB)
	MOVV $1100, R12
	JMP  callbackasm1(SB)
	MOVV $1101, R12
	JMP  callbackasm1(SB)
	MOVV $1102, R12
	JMP  callbackasm1(SB)
	MOVV $1103, R12
	JMP  callbackasm1(SB)
	MOVV $1104, R12
	JMP  callbackasm1(SB)
	MOVV $1105, R12
	JMP  callbackasm1(SB)
	MOVV $1106, R12
	JMP  callbackasm1(SB)
	MOVV $1107, R12
	JMP  callbackasm1(SB)
	MOVV $1108, R12
	JMP  callbackasm1(SB)
	MOVV $1109, R12
	JMP  callbackasm1(SB)
	MOVV $1110, R12
	JMP  callbackasm1(SB)
	MOVV $1111, R12
	JMP  callbackasm1(SB)
	MOVV $1112, R12
	JMP  callbackasm1(SB)
	MOVV $1113, R12
	JMP  callbackasm1(SB)
	MOVV $1114, R12
	JMP  callbackasm1(SB)
	MOVV $1115, R12
	JMP  callbackasm1(SB)
	MOVV $1116, R12
	JMP  callbackasm1(SB)
	MOVV $1117, R12
	JMP  callbackasm1(SB)
	MOVV $1118, R12
	JMP  callbackasm1(SB)
	MOVV $1119, R12
	JMP  callbackasm1(SB)
	MOVV $1120, R12
	JMP  callbackasm1(SB)
	MOVV $1121, R12
	JMP  callbackasm1(SB)
	MOVV $1122, R12
	JMP  callbackasm1(SB)
	MOVV $1123, R12
	JMP  callbackasm1(SB)
	MOVV $1124, R12
	JMP  callbackasm1(SB)
	MOVV $1125, R12
	JMP  callbackasm1(SB)
	MOVV $1126, R12
	JMP  callbackasm1(SB)
	MOVV $1127, R12
	JMP  callbackasm1(SB)
	MOVV $1128, R12
	JMP  callbackasm1(SB)
	MOVV $1129, R12
	JMP  callbackasm1(SB)
	MOVV $1130, R12
	JMP  callbackasm1(SB)
	MOVV $1131, R12
	JMP  callbackasm1(SB)
	MOVV $1132, R12
	JMP  callbackasm1(SB)
	MOVV $1133, R12
	JMP  callbackasm1(SB)
	MOVV $1134, R12
	JMP  callbackasm1(SB)
	MOVV $1135, R12
	JMP  callbackasm1(SB)
	MOVV $1136, R12
	JMP  callbackasm1(SB)
	MOVV $1137, R12
	JMP  callbackasm1(SB)
	MOVV $1138, R12
	JMP  callbackasm1(SB)
	MOVV $1139, R12
	JMP  callbackasm1(SB)
	MOVV $1140, R12
	JMP  callbackasm1(SB)
	MOVV $1141, R12
	JMP  callbackasm1(SB)
	MOVV $1142, R12
	JMP  callbackasm1(SB)
	MOVV $1143, R12
	JMP  callbackasm1(SB)
	MOVV $1144, R12
	JMP  callbackasm1(SB)
	MOVV $1145, R12
	JMP  callbackasm1(SB)
	MOVV $1146, R12
	JMP  callbackasm1(SB)
	MOVV $1147, R12
	JMP  callbackasm1(SB)
	MOVV $1148, R12
	JMP  callbackasm1(SB)
	MOVV $1149, R12
	JMP  callbackasm1(SB)
	MOVV $1150, R12
	JMP  callbackasm1(SB)
	MOVV $1151, R12
	JMP  callbackasm1(SB)
	MOVV $1152, R12
	JMP  callbackasm1(SB)
	MOVV $1153, R12
	JMP  callbackasm1(SB)
	MOVV $1154, R12
	JMP  callbackasm1(SB)
	MOVV $1155, R12
	JMP  callbackasm1(SB)
	MOVV $1156, R12
	JMP  callbackasm1(SB)
	MOVV $1157, R12
	JMP  callbackasm1(SB)
	MOVV $1158, R12
	JMP  callbackasm1(SB)
	MOVV $1159, R12
	JMP  callbackasm1(SB)
	MOVV $1160, R12
	JMP  callbackasm1(SB)
	MOVV $1161, R12
	JMP  callbackasm1(SB)
	MOVV $1162, R12
	JMP  callbackasm1(SB)
	MOVV $1163, R12
	JMP  callbackasm1(SB)
	MOVV $1164, R12
	JMP  callbackasm1(SB)
	MOVV $1165, R12
	JMP  callbackasm1(SB)
	MOVV $1166, R12
	JMP  callbackasm1(SB)
	MOVV $1167, R12
	JMP  callbackasm1(SB)
	MOVV $1168, R12
	JMP  callbackasm1(SB)
	MOVV $1169, R12
	JMP  callbackasm1(SB)
	MOVV $1170, R12
	JMP  callbackasm1(SB)
	MOVV $1171, R12
	JMP  callbackasm1(SB)
	MOVV $1172, R12
	JMP  callbackasm1(SB)
	MOVV $1173, R12
	JMP  callbackasm1(SB)
	MOVV $1174, R12
	JMP  callbackasm1(SB)
	MOVV $1175, R12
	JMP  callbackasm1(SB)
	MOVV $1176, R12
	JMP  callbackasm1(SB)
	MOVV $1177, R12
	JMP  callbackasm1(SB)
	MOVV $1178, R12
	JMP  callbackasm1(SB)
	MOVV $1179, R12
	JMP  callbackasm1(SB)
	MOVV $1180, R12
	JMP  callbackasm1(SB)
	MOVV $1181, R12
	JMP  callbackasm1(SB)
	MOVV $1182, R12
	JMP  callbackasm1(SB)
	MOVV $1183, R12
	JMP  callbackasm1(SB)
	MOVV $1184, R12
	JMP  callbackasm1(SB)
	MOVV $1185, R12
	JMP  callbackasm1(SB)
	MOVV $1186, R12
	JMP  callbackasm1(SB)
	MOVV $1187, R12
	JMP  callbackasm1(SB)
	MOVV $1188, R12
	JMP  callbackasm1(SB)
	MOVV $1189, R12
	JMP  callbackasm1(SB)
	MOVV $1190, R12
	JMP  callbackasm1(SB)
	MOVV $1191, R12
	JMP  callbackasm1(SB)
	MOVV $1192, R12
	JMP  callbackasm1(SB)
	MOVV $1193, R12
	JMP  callbackasm1(SB)
	MOVV $1194, R12
	JMP  callbackasm1(SB)
	MOVV $1195, R12
	JMP  callbackasm1(SB)
	MOVV $1196, R12
	JMP  callbackasm1(SB)
	MOVV $1197, R12
	JMP  callbackasm1(SB)
	MOVV $1198, R12
	JMP  callbackasm1(SB)
	MOVV $1199, R12
	JMP  callbackasm1(SB)
	MOVV $1200, R12
	JMP  callbackasm1(SB)
	MOVV $1201, R12
	JMP  callbackasm1(SB)
	MOVV $1202, R12
	JMP  callbackasm1(SB)
	MOVV $1203, R12
	JMP  callbackasm1(SB)
	MOVV $1204, R12
	JMP  callbackasm1(SB)
	MOVV $1205, R12
	JMP  callbackasm1(SB)
	MOVV $1206, R12
	JMP  callbackasm1(SB)
	MOVV $1207, R12
	JMP  callbackasm1(SB)
	MOVV $1208, R12
	JMP  callbackasm1(SB)
	MOVV $1209, R12
	JMP  callbackasm1(SB)
	MOVV $1210, R12
	JMP  callbackasm1(SB)
	MOVV $1211, R12
	JMP  callbackasm1(SB)
	MOVV $1212, R12
	JMP  callbackasm1(SB)
	MOVV $1213, R12
	JMP  callbackasm1(SB)
	MOVV $1214, R12
	JMP  callbackasm1(SB)
	MOVV $1215, R12
	JMP  callbackasm1(SB)
	MOVV $1216, R12
	JMP  callbackasm1(SB)
	MOVV $1217, R12
	JMP  callbackasm1(SB)
	MOVV $1218, R12
	JMP  callbackasm1(SB)
	MOVV $1219, R12
	JMP  callbackasm1(SB)
	MOVV $1220, R12
	JMP  callbackasm1(SB)
	MOVV $1221, R12
	JMP  callbackasm1(SB)
	MOVV $1222, R12
	JMP  callbackasm1(SB)
	MOVV $1223, R12
	JMP  callbackasm1(SB)
	MOVV $1224, R12
	JMP  callbackasm1(SB)
	MOVV $1225, R12
	JMP  callbackasm1(SB)
	MOVV $1226, R12
	JMP  callbackasm1(SB)
	MOVV $1227, R12
	JMP  callbackasm1(SB)
	MOVV $1228, R12
	JMP  callbackasm1(SB)
	MOVV $1229, R12
	JMP  callbackasm1(SB)
	MOVV $1230, R12
	JMP  callbackasm1(SB)
	MOVV $1231, R12
	JMP  callbackasm1(SB)
	MOVV $1232, R12
	JMP  callbackasm1(SB)
	MOVV $1233, R12
	JMP  callbackasm1(SB)
	MOVV $1234, R12
	JMP  callbackasm1(SB)
	MOVV $1235, R12
	JMP  callbackasm1(SB)
	MOVV $1236, R12
	JMP  callbackasm1(SB)
	MOVV $1237, R12
	JMP  callbackasm1(SB)
	MOVV $1238, R12
	JMP  callbackasm1(SB)
	MOVV $1239, R12
	JMP  callbackasm1(SB)
	MOVV $1240, R12
	JMP  callbackasm1(SB)
	MOVV $1241, R12
	JMP  callbackasm1(SB)
	MOVV $1242, R12
	JMP  callbackasm1(SB)
	MOVV $1243, R12
	JMP  callbackasm1(SB)
	MOVV $1244, R12
	JMP  callbackasm1(SB)
	MOVV $1245, R12
	JMP  callbackasm1(SB)
	MOVV $1246, R12
	JMP  callbackasm1(SB)
	MOVV $1247, R12
	JMP  callbackasm1(SB)
	MOVV $1248, R12
	JMP  callbackasm1(SB)
	MOVV $1249, R12
	JMP  callbackasm1(SB)
	MOVV $1250, R12
	JMP  callbackasm1(SB)
	MOVV $1251, R12
	JMP  callbackasm1(SB)
	MOVV $1252, R12
	JMP  callbackasm1(SB)
	MOVV $1253, R12
	JMP  callbackasm1(SB)
	MOVV $1254, R12
	JMP  callbackasm1(SB)
	MOVV $1255, R12
	JMP  callbackasm1(SB)
	MOVV $1256, R12
	JMP  callbackasm1(SB)
	MOVV $1257, R12
	JMP  callbackasm1(SB)
	MOVV $1258, R12
	JMP  callbackasm1(SB)
	MOVV $1259, R12
	JMP  callbackasm1(SB)
	MOVV $1260, R12
	JMP  callbackasm1(SB)
	MOVV $1261, R12
	JMP  callbackasm1(SB)
	MOVV $1262, R12
	JMP  callbackasm1(SB)
	MOVV $1263, R12
	JMP  callbackasm1(SB)
	MOVV $1264, R12
	JMP  callbackasm1(SB)
	MOVV $1265, R12
	JMP  callbackasm1(SB)
	MOVV $1266, R12
	JMP  callbackasm1(SB)
	MOVV $1267, R12
	JMP  callbackasm1(SB)
	MOVV $1268, R12
	JMP  callbackasm1(SB)
	MOVV $1269, R12
	JMP  callbackasm1(SB)
	MOVV $1270, R12
	JMP  callbackasm1(SB)
	MOVV $1271, R12
	JMP  callbackasm1(SB)
	MOVV $1272, R12
	JMP  callbackasm1(SB)
	MOVV $1273, R12
	JMP  callbackasm1(SB)
	MOVV $1274, R12
	JMP  callbackasm1(SB)
	MOVV $1275, R12
	JMP  callbackasm1(SB)
	MOVV $1276, R12
	JMP  callbackasm1(SB)
	MOVV $1277, R12
	JMP  callbackasm1(SB)
	MOVV $1278, R12
	JMP  callbackasm1(SB)
	MOVV $1279, R12
	JMP  callbackasm1(SB)
	MOVV $1280, R12
	JMP  callbackasm1(SB)
	MOVV $1281, R12
	JMP  callbackasm1(SB)
	MOVV $1282, R12
	JMP  callbackasm1(SB)
	MOVV $1283, R12
	JMP  callbackasm1(SB)
	MOVV $1284, R12
	JMP  callbackasm1(SB)
	MOVV $1285, R12
	JMP  callbackasm1(SB)
	MOVV $1286, R12
	JMP  callbackasm1(SB)
	MOVV $1287, R12
	JMP  callbackasm1(SB)
	MOVV $1288, R12
	JMP  callbackasm1(SB)
	MOVV $1289, R12
	JMP  callbackasm1(SB)
	MOVV $1290, R12
	JMP  callbackasm1(SB)
	MOVV $1291, R12
	JMP  callbackasm1(SB)
	MOVV $1292, R12
	JMP  callbackasm1(SB)
	MOVV $1293, R12
	JMP  callbackasm1(SB)
	MOVV $1294, R12
	JMP  callbackasm1(SB)
	MOVV $1295, R12
	JMP  callbackasm1(SB)
	MOVV $1296, R12
	JMP  callbackasm1(SB)
	MOVV $1297, R12
	JMP  callbackasm1(SB)
	MOVV $1298, R12
	JMP  callbackasm1(SB)
	MOVV $1299, R12
	JMP  callbackasm1(SB)
	MOVV $1300, R12
	JMP  callbackasm1(SB)
	MOVV $1301, R12
	JMP  callbackasm1(SB)
	MOVV $1302, R12
	JMP  callbackasm1(SB)
	MOVV $1303, R12
	JMP  callbackasm1(SB)
	MOVV $1304, R12
	JMP  callbackasm1(SB)
	MOVV $1305, R12
	JMP  callbackasm1(SB)
	MOVV $1306, R12
	JMP  callbackasm1(SB)
	MOVV $1307, R12
	JMP  callbackasm1(SB)
	MOVV $1308, R12
	JMP  callbackasm1(SB)
	MOVV $1309, R12
	JMP  callbackasm1(SB)
	MOVV $1310, R12
	JMP  callbackasm1(SB)
	MOVV $1311, R12
	JMP  callbackasm1(SB)
	MOVV $1312, R12
	JMP  callbackasm1(SB)
	MOVV $1313, R12
	JMP  callbackasm1(SB)
	MOVV $1314, R12
	JMP  callbackasm1(SB)
	MOVV $1315, R12
	JMP  callbackasm1(SB)
	MOVV $1316, R12
	JMP  callbackasm1(SB)
	MOVV $1317, R12
	JMP  callbackasm1(SB)
	MOVV $1318, R12
	JMP  callbackasm1(SB)
	MOVV $1319, R12
	JMP  callbackasm1(SB)
	MOVV $1320, R12
	JMP  callbackasm1(SB)
	MOVV $1321, R12
	JMP  callbackasm1(SB)
	MOVV $1322, R12
	JMP  callbackasm1(SB)
	MOVV $1323, R12
	JMP  callbackasm1(SB)
	MOVV $1324, R12
	JMP  callbackasm1(SB)
	MOVV $1325, R12
	JMP  callbackasm1(SB)
	MOVV $1326, R12
	JMP  callbackasm1(SB)
	MOVV $1327, R12
	JMP  callbackasm1(SB)
	MOVV $1328, R12
	JMP  callbackasm1(SB)
	MOVV $1329, R12
	JMP  callbackasm1(SB)
	MOVV $1330, R12
	JMP  callbackasm1(SB)
	MOVV $1331, R12
	JMP  callbackasm1(SB)
	MOVV $1332, R12
	JMP  callbackasm1(SB)
	MOVV $1333, R12
	JMP  callbackasm1(SB)
	MOVV $1334, R12
	JMP  callbackasm1(SB)
	MOVV $1335, R12
	JMP  callbackasm1(SB)
	MOVV $1336, R12
	JMP  callbackasm1(SB)
	MOVV $1337, R12
	JMP  callbackasm1(SB)
	MOVV $1338, R12
	JMP  callbackasm1(SB)
	MOVV $1339, R12
	JMP  callbackasm1(SB)
	MOVV $1340, R12
	JMP  callbackasm1(SB)
	MOVV $1341, R12
	JMP  callbackasm1(SB)
	MOVV $1342, R12
	JMP  callbackasm1(SB)
	MOVV $1343, R12
	JMP  callbackasm1(SB)
	MOVV $1344, R12
	JMP  callbackasm1(SB)
	MOVV $1345, R12
	JMP  callbackasm1(SB)
	MOVV $1346, R12
	JMP  callbackasm1(SB)
	MOVV $1347, R12
	JMP  callbackasm1(SB)
	MOVV $1348, R12
	JMP  callbackasm1(SB)
	MOVV $1349, R12
	JMP  callbackasm1(SB)
	MOVV $1350, R12
	JMP  callbackasm1(SB)
	MOVV $1351, R12
	JMP  callbackasm1(SB)
	MOVV $1352, R12
	JMP  callbackasm1(SB)
	MOVV $1353, R12
	JMP  callbackasm1(SB)
	MOVV $1354, R12
	JMP  callbackasm1(SB)
	MOVV $1355, R12
	JMP  callbackasm1(SB)
	MOVV $1356, R12
	JMP  callbackasm1(SB)
	MOVV $1357, R12
	JMP  callbackasm1(SB)
	MOVV $1358, R12
	JMP  callbackasm1(SB)
	MOVV $1359, R12
	JMP  callbackasm1(SB)
	MOVV $1360, R12
	JMP  callbackasm1(SB)
	MOVV $1361, R12
	JMP  callbackasm1(SB)
	MOVV $1362, R12
	JMP  callbackasm1(SB)
	MOVV $1363, R12
	JMP  callbackasm1(SB)
	MOVV $1364, R12
	JMP  callbackasm1(SB)
	MOVV $1365, R12
	JMP  callbackasm1(SB)
	MOVV $1366, R12
	JMP  callbackasm1(SB)
	MOVV $1367, R12
	JMP  callbackasm1(SB)
	MOVV $1368, R12
	JMP  callbackasm1(SB)
	MOVV $1369, R12
	JMP  callbackasm1(SB)
	MOVV $1370, R12
	JMP  callbackasm1(SB)
	MOVV $1371, R12
	JMP  callbackasm1(SB)
	MOVV $1372, R12
	JMP  callbackasm1(SB)
	MOVV $1373, R12
	JMP  callbackasm1(SB)
	MOVV $1374, R12
	JMP  callbackasm1(SB)
	MOVV $1375, R12
	JMP  callbackasm1(SB)
	MOVV $1376, R12
	JMP  callbackasm1(SB)
	MOVV $1377, R12
	JMP  callbackasm1(SB)
	MOVV $1378, R12
	JMP  callbackasm1(SB)
	MOVV $1379, R12
	JMP  callbackasm1(SB)
	MOVV $1380, R12
	JMP  callbackasm1(SB)
	MOVV $1381, R12
	JMP  callbackasm1(SB)
	MOVV $1382, R12
	JMP  callbackasm1(SB)
	MOVV $1383, R12
	JMP  callbackasm1(SB)
	MOVV $1384, R12
	JMP  callbackasm1(SB)
	MOVV $1385, R12
	JMP  callbackasm1(SB)
	MOVV $1386, R12
	JMP  callbackasm1(SB)
	MOVV $1387, R12
	JMP  callbackasm1(SB)
	MOVV $1388, R12
	JMP  callbackasm1(SB)
	MOVV $1389, R12
	JMP  callbackasm1(SB)
	MOVV $1390, R12
	JMP  callbackasm1(SB)
	MOVV $1391, R12
	JMP  callbackasm1(SB)
	MOVV $1392, R12
	JMP  callbackasm1(SB)
	MOVV $1393, R12
	JMP  callbackasm1(SB)
	MOVV $1394, R12
	JMP  callbackasm1(SB)
	MOVV $1395, R12
	JMP  callbackasm1(SB)
	MOVV $1396, R12
	JMP  callbackasm1(SB)
	MOVV $1397, R12
	JMP  callbackasm1(SB)
	MOVV $1398, R12
	JMP  callbackasm1(SB)
	MOVV $1399, R12
	JMP  callbackasm1(SB)
	MOVV $1400, R12
	JMP  callbackasm1(SB)
	MOVV $1401, R12
	JMP  callbackasm1(SB)
	MOVV $1402, R12
	JMP  callbackasm1(SB)
	MOVV $1403, R12
	JMP  callbackasm1(SB)
	MOVV $1404, R12
	JMP  callbackasm1(SB)
	MOVV $1405, R12
	JMP  callbackasm1(SB)
	MOVV $1406, R12
	JMP  callbackasm1(SB)
	MOVV $1407, R12
	JMP  callbackasm1(SB)
	MOVV $1408, R12
	JMP  callbackasm1(SB)
	MOVV $1409, R12
	JMP  callbackasm1(SB)
	MOVV $1410, R12
	JMP  callbackasm1(SB)
	MOVV $1411, R12
	JMP  callbackasm1(SB)
	MOVV $1412, R12
	JMP  callbackasm1(SB)
	MOVV $1413, R12
	JMP  callbackasm1(SB)
	MOVV $1414, R12
	JMP  callbackasm1(SB)
	MOVV $1415, R12
	JMP  callbackasm1(SB)
	MOVV $1416, R12
	JMP  callbackasm1(SB)
	MOVV $1417, R12
	JMP  callbackasm1(SB)
	MOVV $1418, R12
	JMP  callbackasm1(SB)
	MOVV $1419, R12
	JMP  callbackasm1(SB)
	MOVV $1420, R12
	JMP  callbackasm1(SB)
	MOVV $1421, R12
	JMP  callbackasm1(SB)
	MOVV $1422, R12
	JMP  callbackasm1(SB)
	MOVV $1423, R12
	JMP  callbackasm1(SB)
	MOVV $1424, R12
	JMP  callbackasm1(SB)
	MOVV $1425, R12
	JMP  callbackasm1(SB)
	MOVV $1426, R12
	JMP  callbackasm1(SB)
	MOVV $1427, R12
	JMP  callbackasm1(SB)
	MOVV $1428, R12
	JMP  callbackasm1(SB)
	MOVV $1429, R12
	JMP  callbackasm1(SB)
	MOVV $1430, R12
	JMP  callbackasm1(SB)
	MOVV $1431, R12
	JMP  callbackasm1(SB)
	MOVV $1432, R12
	JMP  callbackasm1(SB)
	MOVV $1433, R12
	JMP  callbackasm1(SB)
	MOVV $1434, R12
	JMP  callbackasm1(SB)
	MOVV $1435, R12
	JMP  callbackasm1(SB)
	MOVV $1436, R12
	JMP  callbackasm1(SB)
	MOVV $1437, R12
	JMP  callbackasm1(SB)
	MOVV $1438, R12
	JMP  callbackasm1(SB)
	MOVV $1439, R12
	JMP  callbackasm1(SB)
	MOVV $1440, R12
	JMP  callbackasm1(SB)
	MOVV $1441, R12
	JMP  callbackasm1(SB)
	MOVV $1442, R12
	JMP  callbackasm1(SB)
	MOVV $1443, R12
	JMP  callbackasm1(SB)
	MOVV $1444, R12
	JMP  callbackasm1(SB)
	MOVV $1445, R12
	JMP  callbackasm1(SB)
	MOVV $1446, R12
	JMP  callbackasm1(SB)
	MOVV $1447, R12
	JMP  callbackasm1(SB)
	MOVV $1448, R12
	JMP  callbackasm1(SB)
	MOVV $1449, R12
	JMP  callbackasm1(SB)
	MOVV $1450, R12
	JMP  callbackasm1(SB)
	MOVV $1451, R12
	JMP  callbackasm1(SB)
	MOVV $1452, R12
	JMP  callbackasm1(SB)
	MOVV $1453, R12
	JMP  callbackasm1(SB)
	MOVV $1454, R12
	JMP  callbackasm1(SB)
	MOVV $1455, R12
	JMP  callbackasm1(SB)
	MOVV $1456, R12
	JMP  callbackasm1(SB)
	MOVV $1457, R12
	JMP  callbackasm1(SB)
	MOVV $1458, R12
	JMP  callbackasm1(SB)
	MOVV $1459, R12
	JMP  callbackasm1(SB)
	MOVV $1460, R12
	JMP  callbackasm1(SB)
	MOVV $1461, R12
	JMP  callbackasm1(SB)
	MOVV $1462, R12
	JMP  callbackasm1(SB)
	MOVV $1463, R12
	JMP  callbackasm1(SB)
	MOVV $1464, R12
	JMP  callbackasm1(SB)
	MOVV $1465, R12
	JMP  callbackasm1(SB)
	MOVV $1466, R12
	JMP  callbackasm1(SB)
	MOVV $1467, R12
	JMP  callbackasm1(SB)
	MOVV $1468, R12
	JMP  callbackasm1(SB)
	MOVV $1469, R12
	JMP  callbackasm1(SB)
	MOVV $1470, R12
	JMP  callbackasm1(SB)
	MOVV $1471, R12
	JMP  callbackasm1(SB)
	MOVV $1472, R12
	JMP  callbackasm1(SB)
	MOVV $1473, R12
	JMP  callbackasm1(SB)
	MOVV $1474, R12
	JMP  callbackasm1(SB)
	MOVV $1475, R12
	JMP  callbackasm1(SB)
	MOVV $1476, R12
	JMP  callbackasm1(SB)
	MOVV $1477, R12
	JMP  callbackasm1(SB)
	MOVV $1478, R12
	JMP  callbackasm1(SB)
	MOVV $1479, R12
	JMP  callbackasm1(SB)
	MOVV $1480, R12
	JMP  callbackasm1(SB)
	MOVV $1481, R12
	JMP  callbackasm1(SB)
	MOVV $1482, R12
	JMP  callbackasm1(SB)
	MOVV $1483, R12
	JMP  callbackasm1(SB)
	MOVV $1484, R12
	JMP  callbackasm1(SB)
	MOVV $1485, R12
	JMP  callbackasm1(SB)
	MOVV $1486, R12
	JMP  callbackasm1(SB)
	MOVV $1487, R12
	JMP  callbackasm1(SB)
	MOVV $1488, R12
	JMP  callbackasm1(SB)
	MOVV $1489, R12
	JMP  callbackasm1(SB)
	MOVV $1490, R12
	JMP  callbackasm1(SB)
	MOVV $1491, R12
	JMP  callbackasm1(SB)
	MOVV $1492, R12
	JMP  callbackasm1(SB)
	MOVV $1493, R12
	JMP  callbackasm1(SB)
	MOVV $1494, R12
	JMP  callbackasm1(SB)
	MOVV $1495, R12
	JMP  callbackasm1(SB)
	MOVV $1496, R12
	JMP  callbackasm1(SB)
	MOVV $1497, R12
	JMP  callbackasm1(SB)
	MOVV $1498, R12
	JMP  callbackasm1(SB)
	MOVV $1499, R12
	JMP  callbackasm1(SB)
	MOVV $1500, R12
	JMP  callbackasm1(SB)
	MOVV $1501, R12
	JMP  callbackasm1(SB)
	MOVV $1502, R12
	JMP  callbackasm1(SB)
	MOVV $1503, R12
	JMP  callbackasm1(SB)
	MOVV $1504, R12
	JMP  callbackasm1(SB)
	MOVV $1505, R12
	JMP  callbackasm1(SB)
	MOVV $1506, R12
	JMP  callbackasm1(SB)
	MOVV $1507, R12
	JMP  callbackasm1(SB)
	MOVV $1508, R12
	JMP  callbackasm1(SB)
	MOVV $1509, R12
	JMP  callbackasm1(SB)
	MOVV $1510, R12
	JMP  callbackasm1(SB)
	MOVV $1511, R12
	JMP  callbackasm1(SB)
	MOVV $1512, R12
	JMP  callbackasm1(SB)
	MOVV $1513, R12
	JMP  callbackasm1(SB)
	MOVV $1514, R12
	JMP  callbackasm1(SB)
	MOVV $1515, R12
	JMP  callbackasm1(SB)
	MOVV $1516, R12
	JMP  callbackasm1(SB)
	MOVV $1517, R12
	JMP  callbackasm1(SB)
	MOVV $1518, R12
	JMP  callbackasm1(SB)
	MOVV $1519, R12
	JMP  callbackasm1(SB)
	MOVV $1520, R12
	JMP  callbackasm1(SB)
	MOVV $1521, R12
	JMP  callbackasm1(SB)
	MOVV $1522, R12
	JMP  callbackasm1(SB)
	MOVV $1523, R12
	JMP  callbackasm1(SB)
	MOVV $1524, R12
	JMP  callbackasm1(SB)
	MOVV $1525, R12
	JMP  callbackasm1(SB)
	MOVV $1526, R12
	JMP  callbackasm1(SB)
	MOVV $1527, R12
	JMP  callbackasm1(SB)
	MOVV $1528, R12
	JMP  callbackasm1(SB)
	MOVV $1529, R12
	JMP  callbackasm1(SB)
	MOVV $1530, R12
	JMP  callbackasm1(SB)
	MOVV $1531, R12
	JMP  callbackasm1(SB)
	MOVV $1532, R12
	JMP  callbackasm1(SB)
	MOVV $1533, R12
	JMP  callbackasm1(SB)
	MOVV $1534, R12
	JMP  callbackasm1(SB)
	MOVV $1535, R12
	JMP  callbackasm1(SB)
	MOVV $1536, R12
	JMP  callbackasm1(SB)
	MOVV $1537, R12
	JMP  callbackasm1(SB)
	MOVV $1538, R12
	JMP  callbackasm1(SB)
	MOVV $1539, R12
	JMP  callbackasm1(SB)
	MOVV $1540, R12
	JMP  callbackasm1(SB)
	MOVV $1541, R12
	JMP  callbackasm1(SB)
	MOVV $1542, R12
	JMP  callbackasm1(SB)
	MOVV $1543, R12
	JMP  callbackasm1(SB)
	MOVV $1544, R12
	JMP  callbackasm1(SB)
	MOVV $1545, R12
	JMP  callbackasm1(SB)
	MOVV $1546, R12
	JMP  callbackasm1(SB)
	MOVV $1547, R12
	JMP  callbackasm1(SB)
	MOVV $1548, R12
	JMP  callbackasm1(SB)
	MOVV $1549, R12
	JMP  callbackasm1(SB)
	MOVV $1550, R12
	JMP  callbackasm1(SB)
	MOVV $1551, R12
	JMP  callbackasm1(SB)
	MOVV $1552, R12
	JMP  callbackasm1(SB)
	MOVV $1553, R12
	JMP  callbackasm1(SB)
	MOVV $1554, R12
	JMP  callbackasm1(SB)
	MOVV $1555, R12
	JMP  callbackasm1(SB)
	MOVV $1556, R12
	JMP  callbackasm1(SB)
	MOVV $1557, R12
	JMP  callbackasm1(SB)
	MOVV $1558, R12
	JMP  callbackasm1(SB)
	MOVV $1559, R12
	JMP  callbackasm1(SB)
	MOVV $1560, R12
	JMP  callbackasm1(SB)
	MOVV $1561, R12
	JMP  callbackasm1(SB)
	MOVV $1562, R12
	JMP  callbackasm1(SB)
	MOVV $1563, R12
	JMP  callbackasm1(SB)
	MOVV $1564, R12
	JMP  callbackasm1(SB)
	MOVV $1565, R12
	JMP  callbackasm1(SB)
	MOVV $1566, R12
	JMP  callbackasm1(SB)
	MOVV $1567, R12
	JMP  callbackasm1(SB)
	MOVV $1568, R12
	JMP  callbackasm1(SB)
	MOVV $1569, R12
	JMP  callbackasm1(SB)
	MOVV $1570, R12
	JMP  callbackasm1(SB)
	MOVV $1571, R12
	JMP  callbackasm1(SB)
	MOVV $1572, R12
	JMP  callbackasm1(SB)
	MOVV $1573, R12
	JMP  callbackasm1(SB)
	MOVV $1574, R12
	JMP  callbackasm1(SB)
	MOVV $1575, R12
	JMP  callbackasm1(SB)
	MOVV $1576, R12
	JMP  callbackasm1(SB)
	MOVV $1577, R12
	JMP  callbackasm1(SB)
	MOVV $1578, R12
	JMP  callbackasm1(SB)
	MOVV $1579, R12
	JMP  callbackasm1(SB)
	MOVV $1580, R12
	JMP  callbackasm1(SB)
	MOVV $1581, R12
	JMP  callbackasm1(SB)
	MOVV $1582, R12
	JMP  callbackasm1(SB)
	MOVV $1583, R12
	JMP  callbackasm1(SB)
	MOVV $1584, R12
	JMP  callbackasm1(SB)
	MOVV $1585, R12
	JMP  callbackasm1(SB)
	MOVV $1586, R12
	JMP  callbackasm1(SB)
	MOVV $1587, R12
	JMP  callbackasm1(SB)
	MOVV $1588, R12
	JMP  callbackasm1(SB)
	MOVV $1589, R12
	JMP  callbackasm1(SB)
	MOVV $1590, R12
	JMP  callbackasm1(SB)
	MOVV $1591, R12
	JMP  callbackasm1(SB)
	MOVV $1592, R12
	JMP  callbackasm1(SB)
	MOVV $1593, R12
	JMP  callbackasm1(SB)
	MOVV $1594, R12
	JMP  callbackasm1(SB)
	MOVV $1595, R12
	JMP  callbackasm1(SB)
	MOVV $1596, R12
	JMP  callbackasm1(SB)
	MOVV $1597, R12
	JMP  callbackasm1(SB)
	MOVV $1598, R12
	JMP  callbackasm1(SB)
	MOVV $1599, R12
	JMP  callbackasm1(SB)
	MOVV $1600, R12
	JMP  callbackasm1(SB)
	MOVV $1601, R12
	JMP  callbackasm1(SB)
	MOVV $1602, R12
	JMP  callbackasm1(SB)
	MOVV $1603, R12
	JMP  callbackasm1(SB)
	MOVV $1604, R12
	JMP  callbackasm1(SB)
	MOVV $1605, R12
	JMP  callbackasm1(SB)
	MOVV $1606, R12
	JMP  callbackasm1(SB)
	MOVV $1607, R12
	JMP  callbackasm1(SB)
	MOVV $1608, R12
	JMP  callbackasm1(SB)
	MOVV $1609, R12
	JMP  callbackasm1(SB)
	MOVV $1610, R12
	JMP  callbackasm1(SB)
	MOVV $1611, R12
	JMP  callbackasm1(SB)
	MOVV $1612, R12
	JMP  callbackasm1(SB)
	MOVV $1613, R12
	JMP  callbackasm1(SB)
	MOVV $1614, R12
	JMP  callbackasm1(SB)
	MOVV $1615, R12
	JMP  callbackasm1(SB)
	MOVV $1616, R12
	JMP  callbackasm1(SB)
	MOVV $1617, R12
	JMP  callbackasm1(SB)
	MOVV $1618, R12
	JMP  callbackasm1(SB)
	MOVV $1619, R12
	JMP  callbackasm1(SB)
	MOVV $1620, R12
	JMP  callbackasm1(SB)
	MOVV $1621, R12
	JMP  callbackasm1(SB)
	MOVV $1622, R12
	JMP  callbackasm1(SB)
	MOVV $1623, R12
	JMP  callbackasm1(SB)
	MOVV $1624, R12
	JMP  callbackasm1(SB)
	MOVV $1625, R12
	JMP  callbackasm1(SB)
	MOVV $1626, R12
	JMP  callbackasm1(SB)
	MOVV $1627, R12
	JMP  callbackasm1(SB)
	MOVV $1628, R12
	JMP  callbackasm1(SB)
	MOVV $1629, R12
	JMP  callbackasm1(SB)
	MOVV $1630, R12
	JMP  callbackasm1(SB)
	MOVV $1631, R12
	JMP  callbackasm1(SB)
	MOVV $1632, R12
	JMP  callbackasm1(SB)
	MOVV $1633, R12
	JMP  callbackasm1(SB)
	MOVV $1634, R12
	JMP  callbackasm1(SB)
	MOVV $1635, R12
	JMP  callbackasm1(SB)
	MOVV $1636, R12
	JMP  callbackasm1(SB)
	MOVV $1637, R12
	JMP  callbackasm1(SB)
	MOVV $1638, R12
	JMP  callbackasm1(SB)
	MOVV $1639, R12
	JMP  callbackasm1(SB)
	MOVV $1640, R12
	JMP  callbackasm1(SB)
	MOVV $1641, R12
	JMP  callbackasm1(SB)
	MOVV $1642, R12
	JMP  callbackasm1(SB)
	MOVV $1643, R12
	JMP  callbackasm1(SB)
	MOVV $1644, R12
	JMP  callbackasm1(SB)
	MOVV $1645, R12
	JMP  callbackasm1(SB)
	MOVV $1646, R12
	JMP  callbackasm1(SB)
	MOVV $1647, R12
	JMP  callbackasm1(SB)
	MOVV $1648, R12
	JMP  callbackasm1(SB)
	MOVV $1649, R12
	JMP  callbackasm1(SB)
	MOVV $1650, R12
	JMP  callbackasm1(SB)
	MOVV $1651, R12
	JMP  callbackasm1(SB)
	MOVV $1652, R12
	JMP  callbackasm1(SB)
	MOVV $1653, R12
	JMP  callbackasm1(SB)
	MOVV $1654, R12
	JMP  callbackasm1(SB)
	MOVV $1655, R12
	JMP  callbackasm1(SB)
	MOVV $1656, R12
	JMP  callbackasm1(SB)
	MOVV $1657, R12
	JMP  callbackasm1(SB)
	MOVV $1658, R12
	JMP  callbackasm1(SB)
	MOVV $1659, R12
	JMP  callbackasm1(SB)
	MOVV $1660, R12
	JMP  callbackasm1(SB)
	MOVV $1661, R12
	JMP  callbackasm1(SB)
	MOVV $1662, R12
	JMP  callbackasm1(SB)
	MOVV $1663, R12
	JMP  callbackasm1(SB)
	MOVV $1664, R12
	JMP  callbackasm1(SB)
	MOVV $1665, R12
	JMP  callbackasm1(SB)
	MOVV $1666, R12
	JMP  callbackasm1(SB)
	MOVV $1667, R12
	JMP  callbackasm1(SB)
	MOVV $1668, R12
	JMP  callbackasm1(SB)
	MOVV $1669, R12
	JMP  callbackasm1(SB)
	MOVV $1670, R12
	JMP  callbackasm1(SB)
	MOVV $1671, R12
	JMP  callbackasm1(SB)
	MOVV $1672, R12
	JMP  callbackasm1(SB)
	MOVV $1673, R12
	JMP  callbackasm1(SB)
	MOVV $1674, R12
	JMP  callbackasm1(SB)
	MOVV $1675, R12
	JMP  callbackasm1(SB)
	MOVV $1676, R12
	JMP  callbackasm1(SB)
	MOVV $1677, R12
	JMP  callbackasm1(SB)
	MOVV $1678, R12
	JMP  callbackasm1(SB)
	MOVV $1679, R12
	JMP  callbackasm1(SB)
	MOVV $1680, R12
	JMP  callbackasm1(SB)
	MOVV $1681, R12
	JMP  callbackasm1(SB)
	MOVV $1682, R12
	JMP  callbackasm1(SB)
	MOVV $1683, R12
	JMP  callbackasm1(SB)
	MOVV $1684, R12
	JMP  callbackasm1(SB)
	MOVV $1685, R12
	JMP  callbackasm1(SB)
	MOVV $1686, R12
	JMP  callbackasm1(SB)
	MOVV $1687, R12
	JMP  callbackasm1(SB)
	MOVV $1688, R12
	JMP  callbackasm1(SB)
	MOVV $1689, R12
	JMP  callbackasm1(SB)
	MOVV $1690, R12
	JMP  callbackasm1(SB)
	MOVV $1691, R12
	JMP  callbackasm1(SB)
	MOVV $1692, R12
	JMP  callbackasm1(SB)
	MOVV $1693, R12
	JMP  callbackasm1(SB)
	MOVV $1694, R12
	JMP  callbackasm1(SB)
	MOVV $1695, R12
	JMP  callbackasm1(SB)
	MOVV $1696, R12
	JMP  callbackasm1(SB)
	MOVV $1697, R12
	JMP  callbackasm1(SB)
	MOVV $1698, R12
	JMP  callbackasm1(SB)
	MOVV $1699, R12
	JMP  callbackasm1(SB)
	MOVV $1700, R12
	JMP  callbackasm1(SB)
	MOVV $1701, R12
	JMP  callbackasm1(SB)
	MOVV $1702, R12
	JMP  callbackasm1(SB)
	MOVV $1703, R12
	JMP  callbackasm1(SB)
	MOVV $1704, R12
	JMP  callbackasm1(SB)
	MOVV $1705, R12
	JMP  callbackasm1(SB)
	MOVV $1706, R12
	JMP  callbackasm1(SB)
	MOVV $1707, R12
	JMP  callbackasm1(SB)
	MOVV $1708, R12
	JMP  callbackasm1(SB)
	MOVV $1709, R12
	JMP  callbackasm1(SB)
	MOVV $1710, R12
	JMP  callbackasm1(SB)
	MOVV $1711, R12
	JMP  callbackasm1(SB)
	MOVV $1712, R12
	JMP  callbackasm1(SB)
	MOVV $1713, R12
	JMP  callbackasm1(SB)
	MOVV $1714, R12
	JMP  callbackasm1(SB)
	MOVV $1715, R12
	JMP  callbackasm1(SB)
	MOVV $1716, R12
	JMP  callbackasm1(SB)
	MOVV $1717, R12
	JMP  callbackasm1(SB)
	MOVV $1718, R12
	JMP  callbackasm1(SB)
	MOVV $1719, R12
	JMP  callbackasm1(SB)
	MOVV $1720, R12
	JMP  callbackasm1(SB)
	MOVV $1721, R12
	JMP  callbackasm1(SB)
	MOVV $1722, R12
	JMP  callbackasm1(SB)
	MOVV $1723, R12
	JMP  callbackasm1(SB)
	MOVV $1724, R12
	JMP  callbackasm1(SB)
	MOVV $1725, R12
	JMP  callbackasm1(SB)
	MOVV $1726, R12
	JMP  callbackasm1(SB)
	MOVV $1727, R12
	JMP  callbackasm1(SB)
	MOVV $1728, R12
	JMP  callbackasm1(SB)
	MOVV $1729, R12
	JMP  callbackasm1(SB)
	MOVV $1730, R12
	JMP  callbackasm1(SB)
	MOVV $1731, R12
	JMP  callbackasm1(SB)
	MOVV $1732, R12
	JMP  callbackasm1(SB)
	MOVV $1733, R12
	JMP  callbackasm1(SB)
	MOVV $1734, R12
	JMP  callbackasm1(SB)
	MOVV $1735, R12
	JMP  callbackasm1(SB)
	MOVV $1736, R12
	JMP  callbackasm1(SB)
	MOVV $1737, R12
	JMP  callbackasm1(SB)
	MOVV $1738, R12
	JMP  callbackasm1(SB)
	MOVV $1739, R12
	JMP  callbackasm1(SB)
	MOVV $1740, R12
	JMP  callbackasm1(SB)
	MOVV $1741, R12
	JMP  callbackasm1(SB)
	MOVV $1742, R12
	JMP  callbackasm1(SB)
	MOVV $1743, R12
	JMP  callbackasm1(SB)
	MOVV $1744, R12
	JMP  callbackasm1(SB)
	MOVV $1745, R12
	JMP  callbackasm1(SB)
	MOVV $1746, R12
	JMP  callbackasm1(SB)
	MOVV $1747, R12
	JMP  callbackasm1(SB)
	MOVV $1748, R12
	JMP  callbackasm1(SB)
	MOVV $1749, R12
	JMP  callbackasm1(SB)
	MOVV $1750, R12
	JMP  callbackasm1(SB)
	MOVV $1751, R12
	JMP  callbackasm1(SB)
	MOVV $1752, R12
	JMP  callbackasm1(SB)
	MOVV $1753, R12
	JMP  callbackasm1(SB)
	MOVV $1754, R12
	JMP  callbackasm1(SB)
	MOVV $1755, R12
	JMP  callbackasm1(SB)
	MOVV $1756, R12
	JMP  callbackasm1(SB)
	MOVV $1757, R12
	JMP  callbackasm1(SB)
	MOVV $1758, R12
	JMP  callbackasm1(SB)
	MOVV $1759, R12
	JMP  callbackasm1(SB)
	MOVV $1760, R12
	JMP  callbackasm1(SB)
	MOVV $1761, R12
	JMP  callbackasm1(SB)
	MOVV $1762, R12
	JMP  callbackasm1(SB)
	MOVV $1763, R12
	JMP  callbackasm1(SB)
	MOVV $1764, R12
	JMP  callbackasm1(SB)
	MOVV $1765, R12
	JMP  callbackasm1(SB)
	MOVV $1766, R12
	JMP  callbackasm1(SB)
	MOVV $1767, R12
	JMP  callbackasm1(SB)
	MOVV $1768, R12
	JMP  callbackasm1(SB)
	MOVV $1769, R12
	JMP  callbackasm1(SB)
	MOVV $1770, R12
	JMP  callbackasm1(SB)
	MOVV $1771, R12
	JMP  callbackasm1(SB)
	MOVV $1772, R12
	JMP  callbackasm1(SB)
	MOVV $1773, R12
	JMP  callbackasm1(SB)
	MOVV $1774, R12
	JMP  callbackasm1(SB)
	MOVV $1775, R12
	JMP  callbackasm1(SB)
	MOVV $1776, R12
	JMP  callbackasm1(SB)
	MOVV $1777, R12
	JMP  callbackasm1(SB)
	MOVV $1778, R12
	JMP  callbackasm1(SB)
	MOVV $1779, R12
	JMP  callbackasm1(SB)
	MOVV $1780, R12
	JMP  callbackasm1(SB)
	MOVV $1781, R12
	JMP  callbackasm1(SB)
	MOVV $1782, R12
	JMP  callbackasm1(SB)
	MOVV $1783, R12
	JMP  callbackasm1(SB)
	MOVV $1784, R12
	JMP  callbackasm1(SB)
	MOVV $1785, R12
	JMP  callbackasm1(SB)
	MOVV $1786, R12
	JMP  callbackasm1(SB)
	MOVV $1787, R12
	JMP  callbackasm1(SB)
	MOVV $1788, R12
	JMP  callbackasm1(SB)
	MOVV $1789, R12
	JMP  callbackasm1(SB)
	MOVV $1790, R12
	JMP  callbackasm1(SB)
	MOVV $1791, R12
	JMP  callbackasm1(SB)
	MOVV $1792, R12
	JMP  callbackasm1(SB)
	MOVV $1793, R12
	JMP  callbackasm1(SB)
	MOVV $1794, R12
	JMP  callbackasm1(SB)
	MOVV $1795, R12
	JMP  callbackasm1(SB)
	MOVV $1796, R12
	JMP  callbackasm1(SB)
	MOVV $1797, R12
	JMP  callbackasm1(SB)
	MOVV $1798, R12
	JMP  callbackasm1(SB)
	MOVV $1799, R12
	JMP  callbackasm1(SB)
	MOVV $1800, R12
	JMP  callbackasm1(SB)
	MOVV $1801, R12
	JMP  callbackasm1(SB)
	MOVV $1802, R12
	JMP  callbackasm1(SB)
	MOVV $1803, R12
	JMP  callbackasm1(SB)
	MOVV $1804, R12
	JMP  callbackasm1(SB)
	MOVV $1805, R12
	JMP  callbackasm1(SB)
	MOVV $1806, R12
	JMP  callbackasm1(SB)
	MOVV $1807, R12
	JMP  callbackasm1(SB)
	MOVV $1808, R12
	JMP  callbackasm1(SB)
	MOVV $1809, R12
	JMP  callbackasm1(SB)
	MOVV $1810, R12
	JMP  callbackasm1(SB)
	MOVV $1811, R12
	JMP  callbackasm1(SB)
	MOVV $1812, R12
	JMP  callbackasm1(SB)
	MOVV $1813, R12
	JMP  callbackasm1(SB)
	MOVV $1814, R12
	JMP  callbackasm1(SB)
	MOVV $1815, R12
	JMP  callbackasm1(SB)
	MOVV $1816, R12
	JMP  callbackasm1(SB)
	MOVV $1817, R12
	JMP  callbackasm1(SB)
	MOVV $1818, R12
	JMP  callbackasm1(SB)
	MOVV $1819, R12
	JMP  callbackasm1(SB)
	MOVV $1820, R12
	JMP  callbackasm1(SB)
	MOVV $1821, R12
	JMP  callbackasm1(SB)
	MOVV $1822, R12
	JMP  callbackasm1(SB)
	MOVV $1823, R12
	JMP  callbackasm1(SB)
	MOVV $1824, R12
	JMP  callbackasm1(SB)
	MOVV $1825, R12
	JMP  callbackasm1(SB)
	MOVV $1826, R12
	JMP  callbackasm1(SB)
	MOVV $1827, R12
	JMP  callbackasm1(SB)
	MOVV $1828, R12
	JMP  callbackasm1(SB)
	MOVV $1829, R12
	JMP  callbackasm1(SB)
	MOVV $1830, R12
	JMP  callbackasm1(SB)
	MOVV $1831, R12
	JMP  callbackasm1(SB)
	MOVV $1832, R12
	JMP  callbackasm1(SB)
	MOVV $1833, R12
	JMP  callbackasm1(SB)
	MOVV $1834, R12
	JMP  callbackasm1(SB)
	MOVV $1835, R12
	JMP  callbackasm1(SB)
	MOVV $1836, R12
	JMP  callbackasm1(SB)
	MOVV $1837, R12
	JMP  callbackasm1(SB)
	MOVV $1838, R12
	JMP  callbackasm1(SB)
	MOVV $1839, R12
	JMP  callbackasm1(SB)
	MOVV $1840, R12
	JMP  callbackasm1(SB)
	MOVV $1841, R12
	JMP  callbackasm1(SB)
	MOVV $1842, R12
	JMP  callbackasm1(SB)
	MOVV $1843, R12
	JMP  callbackasm1(SB)
	MOVV $1844, R12
	JMP  callbackasm1(SB)
	MOVV $1845, R12
	JMP  callbackasm1(SB)
	MOVV $1846, R12
	JMP  callbackasm1(SB)
	MOVV $1847, R12
	JMP  callbackasm1(SB)
	MOVV $1848, R12
	JMP  callbackasm1(SB)
	MOVV $1849, R12
	JMP  callbackasm1(SB)
	MOVV $1850, R12
	JMP  callbackasm1(SB)
	MOVV $1851, R12
	JMP  callbackasm1(SB)
	MOVV $1852, R12
	JMP  callbackasm1(SB)
	MOVV $1853, R12
	JMP  callbackasm1(SB)
	MOVV $1854, R12
	JMP  callbackasm1(SB)
	MOVV $1855, R12
	JMP  callbackasm1(SB)
	MOVV $1856, R12
	JMP  callbackasm1(SB)
	MOVV $1857, R12
	JMP  callbackasm1(SB)
	MOVV $1858, R12
	JMP  callbackasm1(SB)
	MOVV $1859, R12
	JMP  callbackasm1(SB)
	MOVV $1860, R12
	JMP  callbackasm1(SB)
	MOVV $1861, R12
	JMP  callbackasm1(SB)
	MOVV $1862, R12
	JMP  callbackasm1(SB)
	MOVV $1863, R12
	JMP  callbackasm1(SB)
	MOVV $1864, R12
	JMP  callbackasm1(SB)
	MOVV $1865, R12
	JMP  callbackasm1(SB)
	MOVV $1866, R12
	JMP  callbackasm1(SB)
	MOVV $1867, R12
	JMP  callbackasm1(SB)
	MOVV $1868, R12
	JMP  callbackasm1(SB)
	MOVV $1869, R12
	JMP  callbackasm1(SB)
	MOVV $1870, R12
	JMP  callbackasm1(SB)
	MOVV $1871, R12
	JMP  callbackasm1(SB)
	MOVV $1872, R12
	JMP  callbackasm1(SB)
	MOVV $1873, R12
	JMP  callbackasm1(SB)
	MOVV $1874, R12
	JMP  callbackasm1(SB)
	MOVV $1875, R12
	JMP  callbackasm1(SB)
	MOVV $1876, R12
	JMP  callbackasm1(SB)
	MOVV $1877, R12
	JMP  callbackasm1(SB)
	MOVV $1878, R12
	JMP  callbackasm1(SB)
	MOVV $1879, R12
	JMP  callbackasm1(SB)
	MOVV $1880, R12
	JMP  callbackasm1(SB)
	MOVV $1881, R12
	JMP  callbackasm1(SB)
	MOVV $1882, R12
	JMP  callbackasm1(SB)
	MOVV $1883, R12
	JMP  callbackasm1(SB)
	MOVV $1884, R12
	JMP  callbackasm1(SB)
	MOVV $1885, R12
	JMP  callbackasm1(SB)
	MOVV $1886, R12
	JMP  callbackasm1(SB)
	MOVV $1887, R12
	JMP  callbackasm1(SB)
	MOVV $1888, R12
	JMP  callbackasm1(SB)
	MOVV $1889, R12
	JMP  callbackasm1(SB)
	MOVV $1890, R12
	JMP  callbackasm1(SB)
	MOVV $1891, R12
	JMP  callbackasm1(SB)
	MOVV $1892, R12
	JMP  callbackasm1(SB)
	MOVV $1893, R12
	JMP  callbackasm1(SB)
	MOVV $1894, R12
	JMP  callbackasm1(SB)
	MOVV $1895, R12
	JMP  callbackasm1(SB)
	MOVV $1896, R12
	JMP  callbackasm1(SB)
	MOVV $1897, R12
	JMP  callbackasm1(SB)
	MOVV $1898, R12
	JMP  callbackasm1(SB)
	MOVV $1899, R12
	JMP  callbackasm1(SB)
	MOVV $1900, R12
	JMP  callbackasm1(SB)
	MOVV $1901, R12
	JMP  callbackasm1(SB)
	MOVV $1902, R12
	JMP  callbackasm1(SB)
	MOVV $1903, R12
	JMP  callbackasm1(SB)
	MOVV $1904, R12
	JMP  callbackasm1(SB)
	MOVV $1905, R12
	JMP  callbackasm1(SB)
	MOVV $1906, R12
	JMP  callbackasm1(SB)
	MOVV $1907, R12
	JMP  callbackasm1(SB)
	MOVV $1908, R12
	JMP  callbackasm1(SB)
	MOVV $1909, R12
	JMP  callbackasm1(SB)
	MOVV $1910, R12
	JMP  callbackasm1(SB)
	MOVV $1911, R12
	JMP  callbackasm1(SB)
	MOVV $1912, R12
	JMP  callbackasm1(SB)
	MOVV $1913, R12
	JMP  callbackasm1(SB)
	MOVV $1914, R12
	JMP  callbackasm1(SB)
	MOVV $1915, R12
	JMP  callbackasm1(SB)
	MOVV $1916, R12
	JMP  callbackasm1(SB)
	MOVV $1917, R12
	JMP  callbackasm1(SB)
	MOVV $1918, R12
	JMP  callbackasm1(SB)
	MOVV $1919, R12
	JMP  callbackasm1(SB)
	MOVV $1920, R12
	JMP  callbackasm1(SB)
	MOVV $1921, R12
	JMP  callbackasm1(SB)
	MOVV $1922, R12
	JMP  callbackasm1(SB)
	MOVV $1923, R12
	JMP  callbackasm1(SB)
	MOVV $1924, R12
	JMP  callbackasm1(SB)
	MOVV $1925, R12
	JMP  callbackasm1(SB)
	MOVV $1926, R12
	JMP  callbackasm1(SB)
	MOVV $1927, R12
	JMP  callbackasm1(SB)
	MOVV $1928, R12
	JMP  callbackasm1(SB)
	MOVV $1929, R12
	JMP  callbackasm1(SB)
	MOVV $1930, R12
	JMP  callbackasm1(SB)
	MOVV $1931, R12
	JMP  callbackasm1(SB)
	MOVV $1932, R12
	JMP  callbackasm1(SB)
	MOVV $1933, R12
	JMP  callbackasm1(SB)
	MOVV $1934, R12
	JMP  callbackasm1(SB)
	MOVV $1935, R12
	JMP  callbackasm1(SB)
	MOVV $1936, R12
	JMP  callbackasm1(SB)
	MOVV $1937, R12
	JMP  callbackasm1(SB)
	MOVV $1938, R12
	JMP  callbackasm1(SB)
	MOVV $1939, R12
	JMP  callbackasm1(SB)
	MOVV $1940, R12
	JMP  callbackasm1(SB)
	MOVV $1941, R12
	JMP  callbackasm1(SB)
	MOVV $1942, R12
	JMP  callbackasm1(SB)
	MOVV $1943, R12
	JMP  callbackasm1(SB)
	MOVV $1944, R12
	JMP  callbackasm1(SB)
	MOVV $1945, R12
	JMP  callbackasm1(SB)
	MOVV $1946, R12
	JMP  callbackasm1(SB)
	MOVV $1947, R12
	JMP  callbackasm1(SB)
	MOVV $1948, R12
	JMP  callbackasm1(SB)
	MOVV $1949, R12
	JMP  callbackasm1(SB)
	MOVV $1950, R12
	JMP  callbackasm1(SB)
	MOVV $1951, R12
	JMP  callbackasm1(SB)
	MOVV $1952, R12
	JMP  callbackasm1(SB)
	MOVV $1953, R12
	JMP  callbackasm1(SB)
	MOVV $1954, R12
	JMP  callbackasm1(SB)
	MOVV $1955, R12
	JMP  callbackasm1(SB)
	MOVV $1956, R12
	JMP  callbackasm1(SB)
	MOVV $1957, R12
	JMP  callbackasm1(SB)
	MOVV $1958, R12
	JMP  callbackasm1(SB)
	MOVV $1959, R12
	JMP  callbackasm1(SB)
	MOVV $1960, R12
	JMP  callbackasm1(SB)
	MOVV $1961, R12
	JMP  callbackasm1(SB)
	MOVV $1962, R12
	JMP  callbackasm1(SB)
	MOVV $1963, R12
	JMP  callbackasm1(SB)
	MOVV $1964, R12
	JMP  callbackasm1(SB)
	MOVV $1965, R12
	JMP  callbackasm1(SB)
	MOVV $1966, R12
	JMP  callbackasm1(SB)
	MOVV $1967, R12
	JMP  callbackasm1(SB)
	MOVV $1968, R12
	JMP  callbackasm1(SB)
	MOVV $1969, R12
	JMP  callbackasm1(SB)
	MOVV $1970, R12
	JMP  callbackasm1(SB)
	MOVV $1971, R12
	JMP  callbackasm1(SB)
	MOVV $1972, R12
	JMP  callbackasm1(SB)
	MOVV $1973, R12
	JMP  callbackasm1(SB)
	MOVV $1974, R12
	JMP  callbackasm1(SB)
	MOVV $1975, R12
	JMP  callbackasm1(SB)
	MOVV $1976, R12
	JMP  callbackasm1(SB)
	MOVV $1977, R12
	JMP  callbackasm1(SB)
	MOVV $1978, R12
	JMP  callbackasm1(SB)
	MOVV $1979, R12
	JMP  callbackasm1(SB)
	MOVV $1980, R12
	JMP  callbackasm1(SB)
	MOVV $1981, R12
	JMP  callbackasm1(SB)
	MOVV $1982, R12
	JMP  callbackasm1(SB)
	MOVV $1983, R12
	JMP  callbackasm1(SB)
	MOVV $1984, R12
	JMP  callbackasm1(SB)
	MOVV $1985, R12
	JMP  callbackasm1(SB)
	MOVV $1986, R12
	JMP  callbackasm1(SB)
	MOVV $1987, R12
	JMP  callbackasm1(SB)
	MOVV $1988, R12
	JMP  callbackasm1(SB)
	MOVV $1989, R12
	JMP  callbackasm1(SB)
	MOVV $1990, R12
	JMP  callbackasm1(SB)
	MOVV $1991, R12
	JMP  callbackasm1(SB)
	MOVV $1992, R12
	JMP  callbackasm1(SB)
	MOVV $1993, R12
	JMP  callbackasm1(SB)
	MOVV $1994, R12
	JMP  callbackasm1(SB)
	MOVV $1995, R12
	JMP  callbackasm1(SB)
	MOVV $1996, R12
	JMP  callbackasm1(SB)
	MOVV $1997, R12
	JMP  callbackasm1(SB)
	MOVV $1998, R12
	JMP  callbackasm1(SB)
	MOVV $1999, R12
	JMP  callbackasm1(SB)
